@@ -1,16 +1,17 @@
 /*
-   Copyright (c) 2000, 2022, Oracle and/or its affiliates.
+   Copyright (c) 2000, 2024, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
    as published by the Free Software Foundation.
 
-   This program is also distributed with certain software (including
+   This program is designed to work with certain software (including
    but not limited to OpenSSL) that is licensed under separate terms,
    as designated in a particular file or component or in included license
    documentation.  The authors of MySQL hereby grant you an additional
    permission to link the program and your derivative works with the
-   separately licensed software that they have included with MySQL.
+   separately licensed software that they have either included with
+   the program or referenced in the documentation.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -32,8 +33,9 @@
 #include <sys/types.h>
 #include <time.h>
 
-#include "client/client_priv.h"
+#include "client/include/client_priv.h"
 #include "compression.h"
+#include "m_string.h"
 #include "my_alloc.h"
 #include "my_dbug.h"
 #include "my_default.h"
@@ -42,8 +44,11 @@
 #include "my_macros.h"
 #include "my_systime.h"
 #include "mysql/service_mysql_alloc.h"
+#include "mysql/strings/int2str.h"
 #include "mysql_version.h"
+#include "nulls.h"
 #include "print_version.h"
+#include "strxmov.h"
 #include "thr_cond.h"
 #include "thr_mutex.h"
 #include "typelib.h"
@@ -81,11 +86,11 @@ static longlong opt_ignore_lines = -1;
 static uint opt_zstd_compress_level = default_zstd_compression_level;
 static char *opt_compress_algorithm = nullptr;
 
-#include "caching_sha2_passwordopt-vars.h"
-#include "multi_factor_passwordopt-vars.h"
-#include "sslopt-vars.h"
+#include "client/include/caching_sha2_passwordopt-vars.h"
+#include "client/include/multi_factor_passwordopt-vars.h"
+#include "client/include/sslopt-vars.h"
 #if defined(_WIN32)
-static char *shared_memory_base_name = 0;
+static char *shared_memory_base_name = nullptr;
 #endif
 
 static struct my_option my_long_options[] = {
@@ -176,10 +181,10 @@ static struct my_option my_long_options[] = {
      "Use LOW_PRIORITY when updating the table.", &opt_low_priority,
      &opt_low_priority, nullptr, GET_BOOL, NO_ARG, 0, 0, 0, nullptr, 0,
      nullptr},
-#include "multi_factor_passwordopt-longopts.h"
+#include "client/include/multi_factor_passwordopt-longopts.h"
 #ifdef _WIN32
-    {"pipe", 'W', "Use named pipes to connect to server.", 0, 0, 0, GET_NO_ARG,
-     NO_ARG, 0, 0, 0, 0, 0, 0},
+    {"pipe", 'W', "Use named pipes to connect to server.", nullptr, nullptr,
+     nullptr, GET_NO_ARG, NO_ARG, 0, 0, 0, nullptr, 0, nullptr},
 #endif
     {"plugin_dir", OPT_PLUGIN_DIR, "Directory for client-side plugins.",
      &opt_plugin_dir, &opt_plugin_dir, nullptr, GET_STR, REQUIRED_ARG, 0, 0, 0,
@@ -202,16 +207,16 @@ static struct my_option my_long_options[] = {
 #if defined(_WIN32)
     {"shared-memory-base-name", OPT_SHARED_MEMORY_BASE_NAME,
      "Base name of shared memory.", &shared_memory_base_name,
-     &shared_memory_base_name, 0, GET_STR_ALLOC, REQUIRED_ARG, 0, 0, 0, 0, 0,
-     0},
+     &shared_memory_base_name, nullptr, GET_STR_ALLOC, REQUIRED_ARG, 0, 0, 0,
+     nullptr, 0, nullptr},
 #endif
     {"silent", 's', "Be more silent.", &silent, &silent, nullptr, GET_BOOL,
      NO_ARG, 0, 0, 0, nullptr, 0, nullptr},
     {"socket", 'S', "The socket file to use for connection.",
      &opt_mysql_unix_port, &opt_mysql_unix_port, nullptr, GET_STR, REQUIRED_ARG,
      0, 0, 0, nullptr, 0, nullptr},
-#include "caching_sha2_passwordopt-longopts.h"
-#include "sslopt-longopts.h"
+#include "client/include/caching_sha2_passwordopt-longopts.h"
+#include "client/include/sslopt-longopts.h"
 
     {"use-threads", OPT_USE_THREADS,
      "Load files in parallel. The argument is the number "
@@ -280,7 +285,7 @@ static bool get_one_option(int optid, const struct my_option *opt,
       DBUG_PUSH(argument ? argument : "d:t:o");
       debug_check_flag = true;
       break;
-#include "sslopt-case.h"
+#include "client/include/sslopt-case.h"
 
     case 'V':
       print_version();
@@ -289,6 +294,9 @@ static bool get_one_option(int optid, const struct my_option *opt,
     case '?':
       usage();
       exit(0);
+    case 'C':
+      CLIENT_WARN_DEPRECATED("--compress", "--compression-algorithms");
+      break;
   }
   return false;
 }
@@ -326,7 +334,7 @@ static int get_options(int *argc, char ***argv) {
 static int write_to_table(char *filename, MYSQL *mysql) {
   char tablename[FN_REFLEN], hard_path[FN_REFLEN],
       escaped_name[FN_REFLEN * 2 + 1], sql_statement[FN_REFLEN * 16 + 256],
-      *end, *pos;
+      escaped_tablename[FN_REFLEN * 2 + 1], *end;
   DBUG_TRACE;
   DBUG_PRINT("enter", ("filename: %s", filename));
 
@@ -336,10 +344,14 @@ static int write_to_table(char *filename, MYSQL *mysql) {
   else
     my_load_path(hard_path, filename, nullptr); /* filename includes the path */
 
+  mysql_real_escape_string_quote(mysql, escaped_tablename, tablename,
+                                 (unsigned long)strlen(tablename), '`');
+
   if (opt_delete) {
     if (verbose)
       fprintf(stdout, "Deleting the old data from table %s\n", tablename);
-    snprintf(sql_statement, FN_REFLEN * 16 + 256, "DELETE FROM %s", tablename);
+    snprintf(sql_statement, FN_REFLEN * 16 + 256, "DELETE FROM `%s`",
+             escaped_tablename);
     if (mysql_query(mysql, sql_statement))
       return db_error_with_table(mysql, tablename);
   }
@@ -363,11 +375,7 @@ static int write_to_table(char *filename, MYSQL *mysql) {
   if (replace) end = my_stpcpy(end, " REPLACE");
   if (ignore) end = my_stpcpy(end, " IGNORE");
   end = my_stpcpy(end, " INTO TABLE `");
-  /* Turn any ` into `` in table name. */
-  for (pos = tablename; *pos; pos++) {
-    if (*pos == '`') *end++ = '`';
-    *end++ = *pos;
-  }
+  end = my_stpcpy(end, escaped_tablename);
   end = my_stpcpy(end, "`");
 
   if (fields_terminated || enclosed || opt_enclosed || escaped)
@@ -477,7 +485,6 @@ static MYSQL *db_connect(char *host, char *database, char *user, char *) {
     if (mysql) mysql_close(mysql);
     return nullptr;
   }
-  mysql->reconnect = false;
   if (verbose) fprintf(stdout, "Selecting database %s\n", database);
   if (mysql_select_db(mysql, database)) {
     ignore_errors = false;
