@@ -1,15 +1,16 @@
-/* Copyright (c) 2000, 2023, Oracle and/or its affiliates.
+/* Copyright (c) 2000, 2024, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
    as published by the Free Software Foundation.
 
-   This program is also distributed with certain software (including
+   This program is designed to work with certain software (including
    but not limited to OpenSSL) that is licensed under separate terms,
    as designated in a particular file or component or in included license
    documentation.  The authors of MySQL hereby grant you an additional
    permission to link the program and your derivative works with the
-   separately licensed software that they have included with MySQL.
+   separately licensed software that they have either included with
+   the program or referenced in the documentation.
 
    Without limiting anything contained in the foregoing, this file,
    which is part of C Driver for MySQL (Connector/C), is also subject to the
@@ -48,6 +49,7 @@
   --print-defaults	  ; Print the modified command line and exit
   --login-path=login-path-name ; Read options under login-path-name from
                                 the login file.
+  --no-login-paths ; login file is not read.
 */
 
 #include "my_config.h"
@@ -57,7 +59,6 @@
 #include <stdlib.h>
 #include <sys/types.h>
 
-#include "m_ctype.h"
 #include "m_string.h"
 #include "my_aes.h"
 #include "my_alloc.h"
@@ -69,14 +70,18 @@
 #include "my_getopt.h"
 #include "my_inttypes.h"
 #include "my_io.h"
-#include "my_loglevel.h"
 #include "my_macros.h"
 #include "my_psi_config.h"
+#include "mysql/my_loglevel.h"
 #include "mysql/psi/mysql_file.h"
+#include "mysql/strings/m_ctype.h"
 #include "mysql_version.h"  // MYSQL_PERSIST_CONFIG_NAME
 #include "mysys/my_default_priv.h"
 #include "mysys/mysys_priv.h"
 #include "mysys_err.h"
+#include "nulls.h"
+#include "strmake.h"
+#include "strxmov.h"
 #include "typelib.h"
 #ifdef _WIN32
 #include <winbase.h>
@@ -209,7 +214,7 @@ bool no_defaults = false;
 static const char **default_directories = nullptr;
 
 #ifdef _WIN32
-static const char *f_extensions[] = {".ini", ".cnf", 0};
+static const char *f_extensions[] = {".ini", ".cnf", nullptr};
 #else
 static const char *f_extensions[] = {".cnf", nullptr};
 #endif
@@ -345,6 +350,7 @@ int my_search_option_files(const char *conf_file, int *argc, char ***argv,
   const char **dirs;
   char *forced_default_file, *forced_extra_defaults;
   DBUG_TRACE;
+  bool found_no_login_paths_dummy = false;
 
   /* Skip for login file. */
   if (!is_login_file) {
@@ -352,13 +358,14 @@ int my_search_option_files(const char *conf_file, int *argc, char ***argv,
     *args_used += get_defaults_options(
         *argc - *args_used, *argv + *args_used, &forced_default_file,
         &forced_extra_defaults, const_cast<char **>(&my_defaults_group_suffix),
-        const_cast<char **>(&my_login_path), found_no_defaults);
+        const_cast<char **>(&my_login_path), found_no_defaults,
+        &found_no_login_paths_dummy);
 
     if (!my_defaults_group_suffix)
       my_defaults_group_suffix = getenv("MYSQL_GROUP_SUFFIX");
 
     if (forced_extra_defaults && !defaults_already_read) {
-      int error =
+      const int error =
           fn_expand(forced_extra_defaults, my_defaults_extra_file_buffer);
       if (error) return error;
 
@@ -366,7 +373,7 @@ int my_search_option_files(const char *conf_file, int *argc, char ***argv,
     }
 
     if (forced_default_file && !defaults_already_read) {
-      int error = fn_expand(forced_default_file, my_defaults_file_buffer);
+      const int error = fn_expand(forced_default_file, my_defaults_file_buffer);
       if (error) return error;
       my_defaults_file = my_defaults_file_buffer;
     }
@@ -541,7 +548,8 @@ static int handle_default_option(void *in_ctx, const char *group_name,
 /*
   Gets options from the command line, however if --no-defaults
   option is used, --defaults-file & --defaults-extra-file options
-  would be ignored.
+  would be ignored and if --no-login-paths option is used,
+  --login-path option would be ignored.
 
   SYNOPSIS
     get_defaults_options()
@@ -551,6 +559,7 @@ static int handle_default_option(void *in_ctx, const char *group_name,
     extra_defaults              --defaults-extra-file option
     group_suffix                --defaults-group-suffix option
     login_path                  --login-path option
+    found_no_login_paths        --no-login-paths option present or not
 
   RETURN
     # Number of arguments used from *argv
@@ -560,9 +569,11 @@ static int handle_default_option(void *in_ctx, const char *group_name,
 
 int get_defaults_options(int argc, char **argv, char **defaults,
                          char **extra_defaults, char **group_suffix,
-                         char **login_path, bool found_no_defaults) {
+                         char **login_path, bool found_no_defaults,
+                         bool *found_no_login_paths) {
   int org_argc = argc, prev_argc = 0, default_option_count = 0;
   *defaults = *extra_defaults = *group_suffix = *login_path = nullptr;
+  bool found_login_path = false;
 
   while (argc >= 2 && argc != prev_argc) {
     /* Skip program name or previously handled argument */
@@ -594,13 +605,33 @@ int get_defaults_options(int argc, char **argv, char **defaults,
       default_option_count++;
       continue;
     }
-    if (!*login_path && is_prefix(*argv, "--login-path=")) {
+    if (is_prefix(*argv, "--no-login-paths") && !found_login_path) {
+      argc--;
+      default_option_count++;
+      *found_no_login_paths = true;
+      continue;
+    }
+    if (!*login_path && is_prefix(*argv, "--login-path=") &&
+        !*found_no_login_paths) {
       *login_path = *argv + sizeof("--login-path=") - 1;
       argc--;
       default_option_count++;
+      found_login_path = true;
       continue;
     }
   }
+  /* Check if --no-login-paths specified before --no-defaults */
+  if (*found_no_login_paths && !found_no_defaults) {
+    int count = argc;
+    while (count >= 2) {
+      if (is_prefix(*argv, "--no-defaults")) {
+        *found_no_login_paths = false;
+        break;
+      }
+      count--;
+      argv++;
+    }
+  }
   return org_argc - argc;
 }
 
@@ -679,14 +710,18 @@ int my_load_defaults(const char *conf_file, const char **groups, int *argc,
   TYPELIB group;
   bool found_print_defaults = false;
   uint args_used = 0;
-  int error = 0;
+  int error = 0, l_argc = *argc;
   const char **ptr;
   const char **res;
+  char **l_argv = argv[0];
+  char *defaults_dummy, *extra_defaults_dummy, *group_suffix_dummy,
+      *login_path_dummy;
   struct handle_option_ctx ctx;
   const char **dirs;
   char my_login_file[FN_REFLEN];
   bool found_no_defaults = false;
-  uint args_sep = my_getopt_use_args_separator ? 1 : 0;
+  bool found_no_login_paths = false;
+  const uint args_sep = my_getopt_use_args_separator ? 1 : 0;
   DBUG_TRACE;
 
   if ((dirs = init_default_directories(alloc)) == nullptr) goto err;
@@ -697,6 +732,11 @@ int my_load_defaults(const char *conf_file, const char **groups, int *argc,
   if (*argc >= 2 && !strcmp(argv[0][1], "--no-defaults"))
     no_defaults = found_no_defaults = true;
 
+  /* Check if the user doesn't want login file processing */
+  get_defaults_options(l_argc, l_argv, &defaults_dummy, &extra_defaults_dummy,
+                       &group_suffix_dummy, &login_path_dummy,
+                       found_no_defaults, &found_no_login_paths);
+
   group.count = 0;
   group.name = "defaults";
   group.type_names = groups;
@@ -713,7 +753,7 @@ int my_load_defaults(const char *conf_file, const char **groups, int *argc,
     return error;
   }
 
-  if (my_defaults_read_login_file) {
+  if (my_defaults_read_login_file && !found_no_login_paths) {
     /* Read options from login group. */
     if (my_default_get_login_file(my_login_file, sizeof(my_login_file)) &&
         (error = my_search_option_files(my_login_file, argc, argv, &args_used,
@@ -798,7 +838,7 @@ static int search_default_file(Process_option_func opt_handler,
                                const char *config_file, bool is_login_file) {
   const char **ext;
   const char *empty_list[] = {"", nullptr};
-  bool have_ext = fn_ext(config_file)[0] != 0;
+  const bool have_ext = fn_ext(config_file)[0] != 0;
   const char **exts_to_use = have_ext ? empty_list : f_extensions;
 
   for (ext = exts_to_use; *ext; ext++) {
@@ -896,7 +936,7 @@ static int search_default_file_with_ext(Process_option_func opt_handler,
   uint i, rc;
   MY_DIR *search_dir;
   FILEINFO *search_file;
-  myf flags = MYF(report_os_error_on_open ? MY_WME : 0);
+  const myf flags = MYF(report_os_error_on_open ? MY_WME : 0);
 
   if ((dir ? strlen(dir) : 0) + strlen(config_file) >= FN_REFLEN - 3)
     return 0; /* Ignore wrong paths */
@@ -1275,7 +1315,7 @@ static mysql_file_getline_ret mysql_file_getline(char *buff, int size,
 
 void my_print_default_files(const char *conf_file) {
   const char *empty_list[] = {"", nullptr};
-  bool have_ext = fn_ext(conf_file)[0] != 0;
+  const bool have_ext = fn_ext(conf_file)[0] != 0;
   const char **exts_to_use = have_ext ? empty_list : f_extensions;
   char name[FN_REFLEN];
   const char **ext;
@@ -1348,7 +1388,8 @@ void print_defaults(const char *conf_file, const char **groups) {
 --defaults-extra-file=# Read this file after the global files are read.\n\
 --defaults-group-suffix=#\n\
                         Also read groups with concat(group, suffix)\n\
---login-path=#          Read this path from the login file.");
+--login-path=#          Read this path from the login file.\n\
+--no-login-paths        Don't read login paths from the login path file.");
 }
 
 /**
@@ -1377,8 +1418,8 @@ void init_variable_default_paths() {
   }
   default_paths["C:\\my.ini"] = enum_variable_source::GLOBAL;
   default_paths["C:\\my.cnf"] = enum_variable_source::GLOBAL;
-  if (GetModuleFileName(NULL, buffer, (DWORD)sizeof(buffer))) {
-    char *end = strend(buffer), *last = NULL;
+  if (GetModuleFileName(nullptr, buffer, (DWORD)sizeof(buffer))) {
+    char *end = strend(buffer), *last = nullptr;
     for (; end > buffer; end--) {
       if (*end == FN_LIBCHAR) {
         if (last) {
@@ -1450,9 +1491,10 @@ void init_variable_default_paths() {
 */
 void update_variable_source(const char *opt_name, const char *value) {
   string var_name = string(opt_name);
-  string path = (value ? value : string(""));
-  string prefix[] = {"loose_", "disable_", "enable_", "maximum_", "skip_"};
-  uint prefix_count = sizeof(prefix) / sizeof(prefix[0]);
+  const string path = (value ? value : string(""));
+  const string prefix[] = {"loose_", "disable_", "enable_", "maximum_",
+                           "skip_"};
+  const uint prefix_count = sizeof(prefix) / sizeof(prefix[0]);
 
   /* opt_name must be of form --XXXXX which means min length must be 3 */
   if (var_name.length() < 3) return;
@@ -1480,7 +1522,7 @@ void update_variable_source(const char *opt_name, const char *value) {
       /* check if variables are prefixed with skip_ */
       if (id == 4) {
         bool skip_variable = false;
-        string skip_variables[] = {
+        const string skip_variables[] = {
             "skip_name_resolve",     "skip_networking",  "skip_show_database",
             "skip_external_locking", "skip_slave_start", "skip_replica_start"};
         for (uint skip_index = 0;
@@ -1599,9 +1641,9 @@ static size_t my_get_system_windows_directory(char *buffer, size_t size) {
 }
 
 static const char *my_get_module_parent(char *buf, size_t size) {
-  char *last = NULL;
+  char *last = nullptr;
   char *end;
-  if (!GetModuleFileName(NULL, buf, (DWORD)size)) return NULL;
+  if (!GetModuleFileName(nullptr, buf, (DWORD)size)) return nullptr;
   end = strend(buf);
 
   /*
@@ -1645,7 +1687,7 @@ static const char **init_default_directories(MEM_ROOT *alloc) {
 
     errors += add_directory(alloc, "C:/", dirs);
 
-    if (my_get_module_parent(fname_buffer, sizeof(fname_buffer)) != NULL)
+    if (my_get_module_parent(fname_buffer, sizeof(fname_buffer)) != nullptr)
       errors += add_directory(alloc, fname_buffer, dirs);
   }
 
