@@ -1,15 +1,16 @@
-/* Copyright (c) 2015, 2023, Oracle and/or its affiliates.
+/* Copyright (c) 2015, 2024, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
    as published by the Free Software Foundation.
 
-   This program is also distributed with certain software (including
+   This program is designed to work with certain software (including
    but not limited to OpenSSL) that is licensed under separate terms,
    as designated in a particular file or component or in included license
    documentation.  The authors of MySQL hereby grant you an additional
    permission to link the program and your derivative works with the
-   separately licensed software that they have included with MySQL.
+   separately licensed software that they have either included with
+   the program or referenced in the documentation.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -29,18 +30,23 @@
 #include "mysql/components/services/log_builtins.h"
 #include "plugin/group_replication/include/compatibility_module.h"
 #include "plugin/group_replication/include/plugin.h"
+#include "plugin/group_replication/include/plugin_handlers/recovery_metadata.h"
 #include "plugin/group_replication/include/plugin_psi.h"
 #include "plugin/group_replication/include/plugin_server_include.h"
 #include "plugin/group_replication/include/plugin_variables/recovery_endpoints.h"
 #include "plugin/group_replication/include/recovery_channel_state_observer.h"
 #include "plugin/group_replication/include/recovery_state_transfer.h"
+#include "plugin/group_replication/include/services/system_variable/get_system_variable.h"
+#include "string_with_len.h"
 
 using std::string;
 
 Recovery_state_transfer::Recovery_state_transfer(
     char *recovery_channel_name, const string &member_uuid,
     Channel_observation_manager *channel_obsr_mngr)
-    : selected_donor(nullptr),
+    : m_recovery_channel_name(recovery_channel_name),
+      m_until_condition(CHANNEL_UNTIL_VIEW_ID),
+      selected_donor(nullptr),
       group_members(nullptr),
       suitable_donors(
           Malloc_allocator<Group_member_info *>(key_group_member_info)),
@@ -97,7 +103,8 @@ Recovery_state_transfer::~Recovery_state_transfer() {
   mysql_mutex_destroy(&donor_selection_lock);
 }
 
-void Recovery_state_transfer::initialize(const string &rec_view_id) {
+void Recovery_state_transfer::initialize(const string &view_id,
+                                         bool is_vcle_enabled) {
   DBUG_TRACE;
 
   // reset the recovery aborted flag
@@ -110,30 +117,69 @@ void Recovery_state_transfer::initialize(const string &rec_view_id) {
   donor_channel_thread_error = false;
   // reset the retry count
   donor_connection_retry_count = 0;
+  this->view_id.assign(view_id);
+  if (is_vcle_enabled) {
+    m_until_condition = CHANNEL_UNTIL_VIEW_ID;
+  } else {
+    m_until_condition = CHANNEL_UNTIL_APPLIER_AFTER_GTIDS;
+  }
+}
 
-  this->view_id.clear();
-  this->view_id.append(rec_view_id);
+void Recovery_state_transfer::set_until_condition_after_gtids(
+    const std::string &after_gtids) {
+  m_after_gtids.assign(after_gtids);
 }
 
 void Recovery_state_transfer::inform_of_applier_stop(my_thread_id thread_id,
-                                                     bool) {
+                                                     bool aborted) {
   DBUG_TRACE;
+  bool error{false};
 
   /*
     This method doesn't take any locks as it could lead to dead locks between
     the connection process and this method that can be invoked in that context.
-    Since this only affects the recovery loop and the flag is reset at each
     connection, no major concurrency issues should exist.
   */
 
   // Act if:
-  if (
-      // we don't have all the data yet
-      !donor_transfer_finished &&
-      // recovery was not aborted
-      !recovery_aborted &&
+  if (!donor_transfer_finished &&  // we don't have all the data yet
+      !recovery_aborted &&         // recovery was not aborted
       // the signal belongs to the recovery donor channel thread
       donor_connection_interface.is_own_event_applier(thread_id)) {
+    /*
+      if recovery is using CHANNEL_UNTIL_APPLIER_AFTER_GTIDS for start replica
+      until condition then,
+      - if aborted == true :
+        which could be due to some error or sql thread than we should not call
+        end_state_transfer() for successful completion, we should set error so
+        that recovery_thd can error out.
+      - else if aborted != true :
+        then we call end_state_transfer() for successful completion.
+    */
+    if (m_until_condition == CHANNEL_UNTIL_APPLIER_AFTER_GTIDS) {
+      if (aborted) {
+        error = true;
+      } else {
+        DBUG_EXECUTE_IF(
+            "group_replication_recovery_after_gtids_applier_stop_error_out",
+            { error = true; });
+        std::string local_gtid_executed_string;
+        if (!error &&
+            verify_member_has_after_gtids_present(local_gtid_executed_string)) {
+          LogPluginErr(INFORMATION_LEVEL,
+                       ER_GROUP_REPLICATION_RECOVERY_STOPPED_GTID_PRESENT,
+                       m_after_gtids.c_str());
+          end_state_transfer();
+        } else {
+          error = true;
+        }
+      }
+    } else {
+      error = true;
+    }
+  }
+
+  if (error) {
     mysql_mutex_lock(&recovery_lock);
     donor_channel_thread_error = true;
     mysql_cond_broadcast(&recovery_condition);
@@ -242,10 +288,7 @@ int Recovery_state_transfer::update_recovery_process(bool did_members_left) {
     current_donor_uuid.assign(selected_donor->get_uuid());
     current_donor_hostname.assign(selected_donor->get_hostname());
     current_donor_port = selected_donor->get_port();
-    Group_member_info *current_donor =
-        group_member_mgr->get_group_member_info(current_donor_uuid);
-    donor_left = (current_donor == nullptr);
-    delete current_donor;
+    donor_left = !group_member_mgr->is_member_info_present(current_donor_uuid);
   }
 
   /*
@@ -325,8 +368,6 @@ bool Recovery_state_transfer::is_own_event_channel(my_thread_id id) {
 
 void Recovery_state_transfer::build_donor_list(string *selected_donor_uuid) {
   DBUG_TRACE;
-  const Member_version local_member_version =
-      local_member_info->get_member_version();
 
   suitable_donors.clear();
 
@@ -334,24 +375,28 @@ void Recovery_state_transfer::build_donor_list(string *selected_donor_uuid) {
 
   while (member_it != group_members->end()) {
     Group_member_info *member = *member_it;
-    // is online and it's not me
-    string m_uuid(member->get_uuid());
-    bool is_online =
+    const string m_uuid(member->get_uuid());
+    const bool is_online =
         member->get_recovery_status() == Group_member_info::MEMBER_ONLINE;
-    bool not_self = m_uuid.compare(member_uuid);
+    const bool not_self = m_uuid.compare(member_uuid);
     bool valid_donor = false;
-    const Member_version member_version = member->get_member_version();
 
+    // is online and it's not me
     if (is_online && not_self) {
-      if (member_version <= local_member_version) {
-        suitable_donors.push_back(member);
-        valid_donor = true;
-      } else if (Compatibility_module::is_version_8_0_lts(member_version) &&
-                 Compatibility_module::is_version_8_0_lts(
-                     local_member_version)) {
-        suitable_donors.push_back(member);
-        valid_donor = true;
+      const Member_version local_member_version =
+          local_member_info->get_member_version();
+      const Member_version donor_member_version = member->get_member_version();
+      std::set<Member_version> local_and_donor_member_versions;
+      local_and_donor_member_versions.insert(local_member_version);
+      local_and_donor_member_versions.insert(donor_member_version);
 
+      if (donor_member_version <= local_member_version) {
+        suitable_donors.push_back(member);
+        valid_donor = true;
+      } else if (Compatibility_module::do_all_versions_belong_to_the_same_lts(
+                     local_and_donor_member_versions)) {
+        suitable_donors.push_back(member);
+        valid_donor = true;
       } else if (get_allow_local_lower_version_join()) {
         suitable_donors.push_back(member);
         valid_donor = true;
@@ -535,11 +580,71 @@ int Recovery_state_transfer::initialize_donor_connection(std::string hostname,
   return error;
 }
 
+bool Recovery_state_transfer::verify_member_has_after_gtids_present(
+    std::string &local_gtid_executed_string) {
+  Get_system_variable get_system_variable;
+  if (get_system_variable.get_global_gtid_executed(
+          local_gtid_executed_string)) {
+    LogPluginErr(ERROR_LEVEL,
+                 ER_GROUP_REPLICATION_RECOVERY_FETCHING_GTID_EXECUTED_SET);
+    return false;
+  }
+
+  Tsid_map local_tsid_map(nullptr);
+  Gtid_set local_gtid_executed(&local_tsid_map, nullptr);
+  if (local_gtid_executed.add_gtid_text(local_gtid_executed_string.c_str()) !=
+      RETURN_STATUS_OK) {
+    LogPluginErr(ERROR_LEVEL,
+                 ER_GROUP_REPLICATION_RECOVERY_ERROR_ADD_GTID_EXECUTED);
+    return false;
+  }
+
+  Tsid_map donor_tsid_map(nullptr);
+  Gtid_set donor_gtid_executed(&donor_tsid_map, nullptr);
+  if (donor_gtid_executed.add_gtid_text(m_after_gtids.c_str()) !=
+      RETURN_STATUS_OK) {
+    LogPluginErr(ERROR_LEVEL,
+                 ER_GROUP_REPLICATION_RECOVERY_ERROR_ADD_GTID_EXECUTED);
+    return false;
+  }
+
+  if (donor_gtid_executed.is_subset(&local_gtid_executed)) {
+    return true;
+  }
+
+  return false;
+}
+
 int Recovery_state_transfer::start_recovery_donor_threads() {
   DBUG_TRACE;
+  int error = 1;
+  std::string local_gtid_executed_string;
 
-  int error =
-      donor_connection_interface.start_threads(true, true, &view_id, true);
+  /*
+    If recovery is without VCLE which is START REPLICA SQL_AFTER_GTIDS UNTIL
+    clause, then joiner is recovered till Gtid_set sent in Recovery Metadata by
+    sender. But before starting recovery threads it's checked if local member
+    already has those gtid_set present. If present then recovery is skipped.
+  */
+  if (m_until_condition == CHANNEL_UNTIL_APPLIER_AFTER_GTIDS) {
+    if (verify_member_has_after_gtids_present(local_gtid_executed_string)) {
+      LogPluginErr(INFORMATION_LEVEL,
+                   ER_GROUP_REPLICATION_RECOVERY_SKIPPED_GTID_PRESENT,
+                   local_gtid_executed_string.c_str(), m_after_gtids.c_str());
+      end_state_transfer();
+      return 0;
+    } else {
+      // recovery using START REPLICA SQL_AFTER_GTIDS UNTIL clause.
+      error = donor_connection_interface.start_threads(
+          true, true, &m_after_gtids, true, m_until_condition);
+    }
+    /*
+      If recovery is using VCLE which is START REPLICA SQL_VIEW_ID UNTIL clause.
+    */
+  } else if (m_until_condition == CHANNEL_UNTIL_VIEW_ID) {
+    error = donor_connection_interface.start_threads(true, true, &view_id, true,
+                                                     m_until_condition);
+  }
 
   if (!error) {
     DBUG_EXECUTE_IF("pause_after_io_thread_stop_hook", {
@@ -554,6 +659,9 @@ int Recovery_state_transfer::start_recovery_donor_threads() {
           "WAIT_FOR reached_stopping_sql_thread";
       assert(!debug_sync_set_action(current_thd, STRING_WITH_LEN(act)));
     };);
+    DBUG_EXECUTE_IF(
+        "group_replication_recovery_sleep_before_wait_for_connection",
+        { my_sleep(1000000); });
 
     /*
       Register a channel observer to detect SQL/IO thread stops
@@ -578,9 +686,60 @@ int Recovery_state_transfer::start_recovery_donor_threads() {
   bool is_applier_stopped =
       !donor_connection_interface.is_applier_thread_running();
 
-  if (!error && !donor_transfer_finished &&
-      (is_receiver_stopping || is_receiver_stopped || is_applier_stopping ||
-       is_applier_stopped)) {
+  if (m_until_condition == CHANNEL_UNTIL_APPLIER_AFTER_GTIDS) {
+    /*
+      If applier is stopping we should give some time for it to
+      stop, so that we can compare the after gtids set.
+    */
+    const unsigned long sleep_time{100000UL};  // 100 milliseconds
+    constexpr const unsigned long max_channel_stopped_wait_timeout{30UL *
+                                                                   1000000UL};
+    unsigned long channel_stopped_wait_timeout{0};
+    while (!error && !recovery_aborted && !donor_channel_thread_error &&
+           !on_failover && !donor_transfer_finished &&
+           donor_connection_interface.is_applier_thread_stopping() &&
+           channel_stopped_wait_timeout < max_channel_stopped_wait_timeout) {
+      my_sleep(sleep_time);
+      channel_stopped_wait_timeout += sleep_time;
+    }
+
+    /*
+      Check if replication applier thread has stopped:
+      Verify after_gtids received from recovery metadata
+      donor is present on member.
+       - If present, recovery has completed.
+       - If not present, set error.
+    */
+    if (!donor_transfer_finished &&
+        !donor_connection_interface.is_applier_thread_running()) {
+      if (verify_member_has_after_gtids_present(local_gtid_executed_string)) {
+        LogPluginErr(INFORMATION_LEVEL,
+                     ER_GROUP_REPLICATION_RECOVERY_STOPPED_GTID_PRESENT,
+                     m_after_gtids.c_str());
+        end_state_transfer();
+        error = 0;
+      } else {
+        if (!error) {
+          error = 1;
+        }
+        channel_observation_manager->unregister_channel_observer(
+            recovery_channel_observer);
+      }
+    }
+
+    if (!error && !donor_transfer_finished &&
+        (donor_connection_interface.is_receiver_thread_stopping() ||
+         !donor_connection_interface.is_receiver_thread_running() ||
+         donor_connection_interface.is_applier_thread_stopping() ||
+         !donor_connection_interface.is_applier_thread_running())) {
+      error = 1;
+      channel_observation_manager->unregister_channel_observer(
+          recovery_channel_observer);
+    }
+
+  } else if (!error && !donor_transfer_finished &&
+             (is_receiver_stopping || is_receiver_stopped ||
+              is_applier_stopping || is_applier_stopped)) {
     error = 1;
     channel_observation_manager->unregister_channel_observer(
         recovery_channel_observer);
@@ -718,7 +877,12 @@ State_transfer_status Recovery_state_transfer::state_transfer(
                             __FILE__, __LINE__, 0, 0);
 
     /*
-      donor_transfer_finished    -> set by the set_retrieved_cert_info method.
+      donor_transfer_finished    -> When recovery is using CHANNEL_UNTIL_VIEW_ID
+                                 set by the set_retrieved_cert_info method.
+                                 When recovery is using
+                                 CHANNEL_UNTIL_APPLIER_AFTER_GTIDS for start
+                                 replica until condition set by
+                                 inform_of_applier_stop method.
                                  lock: recovery_lock
       recovery_aborted           -> set when stopping recovery
                                  lock: run_lock
