@@ -1,16 +1,17 @@
 /*
-  Copyright (c) 2016, 2023, Oracle and/or its affiliates.
+  Copyright (c) 2016, 2024, Oracle and/or its affiliates.
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.
 
-  This program is also distributed with certain software (including
+  This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
-  separately licensed software that they have included with MySQL.
+  separately licensed software that they have either included with
+  the program or referenced in the documentation.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -178,6 +179,7 @@ class TestLoader : public Loader {
   std::exception_ptr init_all() { return Loader::init_all(); }
   void start_all() { return Loader::start_all(); }
   std::exception_ptr run() { return Loader::run(); }
+  void setup_info() { Loader::setup_info(); }
   std::exception_ptr deinit_all() { return Loader::deinit_all(); }
 
   std::list<std::string> order() const { return this->order_; }
@@ -1735,12 +1737,14 @@ TEST_F(LifecycleTest, NoInstances) {
       "\n"
       "runtime_folder = {prefix}                      \n"
       "config_folder  = {prefix}                      \n"
+      "data_folder    = {prefix}                      \n"
       "                                               \n"
       "[logger]                                       \n"
       "level = DEBUG                                  \n"
       "                                               \n");
   init_test_without_lifecycle_plugin(config_text_);
 
+  loader_.setup_info();
   loader_.run();
 
   refresh_log();
