@@ -1,16 +1,17 @@
 /*
-  Copyright (c) 2019, 2023, Oracle and/or its affiliates.
+  Copyright (c) 2019, 2024, Oracle and/or its affiliates.
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.
 
-  This program is also distributed with certain software (including
+  This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
-  separately licensed software that they have included with MySQL.
+  separately licensed software that they have either included with
+  the program or referenced in the documentation.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -200,18 +201,14 @@ TEST(NetTS_internet, network_v4_with_prefix) {
 }
 
 TEST(NetTS_internet, network_v4_invalid) {
-  ASSERT_EQ(
-      net::ip::make_address("127.0.0."),
-      stdx::make_unexpected(make_error_code(std::errc::invalid_argument)));
-  ASSERT_EQ(
-      net::ip::make_address("127.0.0.1."),
-      stdx::make_unexpected(make_error_code(std::errc::invalid_argument)));
-  ASSERT_EQ(
-      net::ip::make_address("127.0.0,1"),
-      stdx::make_unexpected(make_error_code(std::errc::invalid_argument)));
-  ASSERT_EQ(
-      net::ip::make_address("256.0.0.1"),
-      stdx::make_unexpected(make_error_code(std::errc::invalid_argument)));
+  ASSERT_EQ(net::ip::make_address("127.0.0."),
+            stdx::unexpected(make_error_code(std::errc::invalid_argument)));
+  ASSERT_EQ(net::ip::make_address("127.0.0.1."),
+            stdx::unexpected(make_error_code(std::errc::invalid_argument)));
+  ASSERT_EQ(net::ip::make_address("127.0.0,1"),
+            stdx::unexpected(make_error_code(std::errc::invalid_argument)));
+  ASSERT_EQ(net::ip::make_address("256.0.0.1"),
+            stdx::unexpected(make_error_code(std::errc::invalid_argument)));
 }
 
 TEST(NetTS_internet, network_v6_default_construct) {
@@ -247,24 +244,18 @@ TEST(NetTS_internet, network_v6_with_prefix_and_scope_id) {
 }
 
 TEST(NetTS_internet, make_address_v6_invalid) {
-  ASSERT_EQ(
-      net::ip::make_address("zzz"),
-      stdx::make_unexpected(make_error_code(std::errc::invalid_argument)));
-  ASSERT_EQ(
-      net::ip::make_address("::1::2"),
-      stdx::make_unexpected(make_error_code(std::errc::invalid_argument)));
-  ASSERT_EQ(
-      net::ip::make_address("::1%-1"),
-      stdx::make_unexpected(make_error_code(std::errc::invalid_argument)));
-  ASSERT_EQ(
-      net::ip::make_address("::1%+1"),
-      stdx::make_unexpected(make_error_code(std::errc::invalid_argument)));
-  ASSERT_EQ(
-      net::ip::make_address("::1%abc"),
-      stdx::make_unexpected(make_error_code(std::errc::invalid_argument)));
-  ASSERT_EQ(
-      net::ip::make_address("::1%"),
-      stdx::make_unexpected(make_error_code(std::errc::invalid_argument)));
+  ASSERT_EQ(net::ip::make_address("zzz"),
+            stdx::unexpected(make_error_code(std::errc::invalid_argument)));
+  ASSERT_EQ(net::ip::make_address("::1::2"),
+            stdx::unexpected(make_error_code(std::errc::invalid_argument)));
+  ASSERT_EQ(net::ip::make_address("::1%-1"),
+            stdx::unexpected(make_error_code(std::errc::invalid_argument)));
+  ASSERT_EQ(net::ip::make_address("::1%+1"),
+            stdx::unexpected(make_error_code(std::errc::invalid_argument)));
+  ASSERT_EQ(net::ip::make_address("::1%abc"),
+            stdx::unexpected(make_error_code(std::errc::invalid_argument)));
+  ASSERT_EQ(net::ip::make_address("::1%"),
+            stdx::unexpected(make_error_code(std::errc::invalid_argument)));
 }
 
 /*
@@ -387,8 +378,9 @@ TEST(NetTS_internet, tcp_ipv4_socket_bind_accept_connect) {
               ::testing::Truly(res_has_value));
 
   // should fail with EWOULDBLOCK as nothing connect()ed yet
-  EXPECT_EQ(acceptor.accept(), stdx::make_unexpected(make_error_condition(
-                                   std::errc::operation_would_block)));
+  EXPECT_EQ(
+      acceptor.accept(),
+      stdx::unexpected(make_error_condition(std::errc::operation_would_block)));
   auto local_endp_res = acceptor.local_endpoint();
 
   ASSERT_TRUE(local_endp_res) << local_endp_res.error();
@@ -430,9 +422,9 @@ TEST(NetTS_internet, tcp_ipv4_socket_bind_accept_connect) {
   SCOPED_TRACE("// nothing written, read failed with with would block");
   std::array<char, 5> source{{0x01, 0x02, 0x03, 0x04, 0x05}};
   std::array<char, 16> sink;
-  EXPECT_EQ(net::read(client_sock, net::buffer(sink)),
-            stdx::make_unexpected(
-                make_error_condition(std::errc::operation_would_block)));
+  EXPECT_EQ(
+      net::read(client_sock, net::buffer(sink)),
+      stdx::unexpected(make_error_condition(std::errc::operation_would_block)));
 
   SCOPED_TRACE("// writing");
   auto write_res = net::write(server_sock, net::buffer(source));
@@ -517,9 +509,9 @@ TEST(NetTS_internet, udp_ipv4_socket_bind_sendmsg_recvmsg) {
   SCOPED_TRACE("// up to now, there is no data");
   std::array<char, 16> sink;
   net::ip::udp::endpoint recvfrom_endp;
-  EXPECT_EQ(client_sock.receive_from(net::buffer(sink), recvfrom_endp),
-            stdx::make_unexpected(
-                make_error_condition(std::errc::operation_would_block)));
+  EXPECT_EQ(
+      client_sock.receive_from(net::buffer(sink), recvfrom_endp),
+      stdx::unexpected(make_error_condition(std::errc::operation_would_block)));
 
   SCOPED_TRACE("// send something to " + ss_to_string(client_endp));
   std::array<char, 5> source{{0x01, 0x02, 0x03, 0x04, 0x05}};
@@ -555,8 +547,9 @@ TEST(NetTS_internet, tcp_ipv4_socket_bind_accept_connect_dynbuffer) {
               ::testing::Truly(res_has_value));
 
   // should fail with EWOULDBLOCK as nothing connect()ed yet
-  EXPECT_EQ(acceptor.accept(), stdx::make_unexpected(make_error_condition(
-                                   std::errc::operation_would_block)));
+  EXPECT_EQ(
+      acceptor.accept(),
+      stdx::unexpected(make_error_condition(std::errc::operation_would_block)));
   auto local_endp_res = acceptor.local_endpoint();
 
   ASSERT_TRUE(local_endp_res) << local_endp_res.error();
@@ -598,9 +591,9 @@ TEST(NetTS_internet, tcp_ipv4_socket_bind_accept_connect_dynbuffer) {
   SCOPED_TRACE("// nothing written, read failed with with would block");
   std::array<char, 5> source{{0x01, 0x02, 0x03, 0x04, 0x05}};
   std::vector<char> sink;
-  EXPECT_EQ(net::read(client_sock, net::dynamic_buffer(sink)),
-            stdx::make_unexpected(
-                make_error_condition(std::errc::operation_would_block)));
+  EXPECT_EQ(
+      net::read(client_sock, net::dynamic_buffer(sink)),
+      stdx::unexpected(make_error_condition(std::errc::operation_would_block)));
 
   SCOPED_TRACE("// writing");
   auto write_res = net::write(server_sock, net::buffer(source));
@@ -691,8 +684,9 @@ TEST(NetTS_internet, tcp_ipv6_socket_bind_accept_connect) {
               ::testing::Truly(res_has_value));
 
   // should fail with EWOULDBLOCK
-  EXPECT_EQ(acceptor.accept(), stdx::make_unexpected(make_error_condition(
-                                   std::errc::operation_would_block)));
+  EXPECT_EQ(
+      acceptor.accept(),
+      stdx::unexpected(make_error_condition(std::errc::operation_would_block)));
   auto local_endp_res = acceptor.local_endpoint();
 
   ASSERT_TRUE(local_endp_res);
@@ -728,9 +722,9 @@ TEST(NetTS_internet, tcp_ipv6_socket_bind_accept_connect) {
 
   std::array<char, 5> source{{0x01, 0x02, 0x03, 0x04, 0x05}};
   std::array<char, 16> sink;
-  EXPECT_EQ(net::read(client_sock, net::buffer(sink)),
-            stdx::make_unexpected(
-                make_error_condition(std::errc::operation_would_block)));
+  EXPECT_EQ(
+      net::read(client_sock, net::buffer(sink)),
+      stdx::unexpected(make_error_condition(std::errc::operation_would_block)));
 
   SCOPED_TRACE("// send something");
   auto write_res = net::write(server_sock, net::buffer(source));
@@ -792,9 +786,9 @@ TEST(NetTS_internet, udp_ipv6_socket_bind_accept_connect) {
   SCOPED_TRACE("// up to now, there is no data");
   std::array<char, 16> sink;
   net::ip::udp::endpoint recvfrom_endp;
-  EXPECT_EQ(client_sock.receive_from(net::buffer(sink), recvfrom_endp),
-            stdx::make_unexpected(
-                make_error_condition(std::errc::operation_would_block)));
+  EXPECT_EQ(
+      client_sock.receive_from(net::buffer(sink), recvfrom_endp),
+      stdx::unexpected(make_error_condition(std::errc::operation_would_block)));
 
   SCOPED_TRACE("// send something to " + ss_to_string(client_endp));
   std::array<char, 5> source{{0x01, 0x02, 0x03, 0x04, 0x05}};
