@@ -1,16 +1,17 @@
 /*
-  Copyright (c) 2023, Oracle and/or its affiliates.
+  Copyright (c) 2023, 2024, Oracle and/or its affiliates.
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.
 
-  This program is also distributed with certain software (including
+  This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
-  separately licensed software that they have included with MySQL.
+  separately licensed software that they have either included with
+  the program or referenced in the documentation.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -217,7 +218,7 @@ class FixedIntCodec : public impl::EncodeBase<FixedIntCodec<T>> {
     impl::DecodeBufferAccumulator accu(buffer, caps);
 
     auto value_res = accu.template step<wire::FixedInt<byte_size>>();
-    if (!accu.result()) return stdx::make_unexpected(accu.result().error());
+    if (!accu.result()) return stdx::unexpected(accu.result().error());
 
     return std::make_pair(accu.result().value(),
                           value_type(value_res->value()));
@@ -271,7 +272,7 @@ class FloatCodec : public impl::EncodeBase<FloatCodec<T>> {
     impl::DecodeBufferAccumulator accu(buffer, caps);
 
     auto value_res = accu.template step<borrowed::wire::String>(byte_size);
-    if (!accu.result()) return stdx::make_unexpected(accu.result().error());
+    if (!accu.result()) return stdx::unexpected(accu.result().error());
 
     typename T::value_type val;
 
@@ -311,7 +312,7 @@ class StringCodec : public impl::EncodeBase<StringCodec<Borrowed, T>> {
     impl::DecodeBufferAccumulator accu(buffer, caps);
 
     auto value_res = accu.template step<borrowable::wire::String<Borrowed>>();
-    if (!accu.result()) return stdx::make_unexpected(accu.result().error());
+    if (!accu.result()) return stdx::unexpected(accu.result().error());
 
     return std::make_pair(accu.result().value(),
                           value_type(value_res->value()));
@@ -370,7 +371,7 @@ class DatetimeCodec : public impl::EncodeBase<DatetimeCodec<T>> {
 
     auto month_res = accu.template step<wire::FixedInt<1>>();
     auto day_res = accu.template step<wire::FixedInt<1>>();
-    if (!accu.result()) return stdx::make_unexpected(accu.result().error());
+    if (!accu.result()) return stdx::unexpected(accu.result().error());
 
     auto hour_res = accu.template try_step<wire::FixedInt<1>>();
     if (!hour_res) {
@@ -381,7 +382,7 @@ class DatetimeCodec : public impl::EncodeBase<DatetimeCodec<T>> {
 
     auto minute_res = accu.template step<wire::FixedInt<1>>();
     auto second_res = accu.template step<wire::FixedInt<1>>();
-    if (!accu.result()) return stdx::make_unexpected(accu.result().error());
+    if (!accu.result()) return stdx::unexpected(accu.result().error());
 
     auto microsecond_res = accu.template try_step<wire::FixedInt<4>>();
     if (!microsecond_res) {
@@ -392,7 +393,7 @@ class DatetimeCodec : public impl::EncodeBase<DatetimeCodec<T>> {
                      second_res->value()));
     }
 
-    if (!accu.result()) return stdx::make_unexpected(accu.result().error());
+    if (!accu.result()) return stdx::unexpected(accu.result().error());
 
     return std::make_pair(
         accu.result().value(),
@@ -451,7 +452,7 @@ class TimeCodec : public impl::EncodeBase<TimeCodec<T>> {
     auto microsecond_res = accu.template try_step<wire::FixedInt<4>>();
 
     if (!microsecond_res) {
-      if (!accu.result()) return stdx::make_unexpected(accu.result().error());
+      if (!accu.result()) return stdx::unexpected(accu.result().error());
 
       return std::make_pair(
           accu.result().value(),
@@ -460,7 +461,7 @@ class TimeCodec : public impl::EncodeBase<TimeCodec<T>> {
                      second_res->value()));
     }
 
-    if (!accu.result()) return stdx::make_unexpected(accu.result().error());
+    if (!accu.result()) return stdx::unexpected(accu.result().error());
 
     return std::make_pair(
         accu.result().value(),
