@@ -1,16 +1,17 @@
 /*
-  Copyright (c) 2020, 2023, Oracle and/or its affiliates.
+  Copyright (c) 2020, 2024, Oracle and/or its affiliates.
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.
 
-  This program is also distributed with certain software (including
+  This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
-  separately licensed software that they have included with MySQL.
+  separately licensed software that they have either included with
+  the program or referenced in the documentation.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -38,16 +39,12 @@ MY_COMPILER_DIAGNOSTIC_POP()
 extern "C" {
 
 mysql_harness::Plugin ROUTER_PROTOBUF_EXPORT harness_plugin_router_protobuf = {
-    mysql_harness::PLUGIN_ABI_VERSION,
-    mysql_harness::ARCHITECTURE_DESCRIPTOR,
-    "",
-    VERSION_NUMBER(0, 0, 1),
+    mysql_harness::PLUGIN_ABI_VERSION, mysql_harness::ARCHITECTURE_DESCRIPTOR,
+    "", VERSION_NUMBER(0, 0, 1),
     // requires
-    0,
-    nullptr,
+    0, nullptr,
     // conflicts
-    0,
-    nullptr,
+    0, nullptr,
     nullptr,  // init
     [](mysql_harness::PluginFuncEnv *) {
       google::protobuf::ShutdownProtobufLibrary();
@@ -55,7 +52,7 @@ mysql_harness::Plugin ROUTER_PROTOBUF_EXPORT harness_plugin_router_protobuf = {
     nullptr,  // start
     nullptr,  // stop
     false,    // declare_readiness
-    0,
-    nullptr,
+    0, nullptr,
+    nullptr,  // expose_configuration
 };
 }
