@@ -1,16 +1,17 @@
 /*
-  Copyright (c) 2016, 2023, Oracle and/or its affiliates.
+  Copyright (c) 2016, 2024, Oracle and/or its affiliates.
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.
 
-  This program is also distributed with certain software (including
+  This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
-  separately licensed software that they have included with MySQL.
+  separately licensed software that they have either included with
+  the program or referenced in the documentation.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -451,14 +452,13 @@ static MysqlError make_mysql_error_code(MYSQL *m) {
 stdx::expected<MySQLSession::mysql_result_type, MysqlError>
 MySQLSession::real_query(const std::string &q) {
   if (!connected_) {
-    return stdx::make_unexpected(
-        make_mysql_error_code(CR_COMMANDS_OUT_OF_SYNC));
+    return stdx::unexpected(make_mysql_error_code(CR_COMMANDS_OUT_OF_SYNC));
   }
 
   auto query_res = mysql_real_query(connection_, q.data(), q.size());
 
   if (query_res != 0) {
-    return stdx::make_unexpected(make_mysql_error_code(connection_));
+    return stdx::unexpected(make_mysql_error_code(connection_));
   }
 
   mysql_result_type res{mysql_store_result(connection_)};
@@ -466,7 +466,7 @@ MySQLSession::real_query(const std::string &q) {
     // no error, but also no resultset
     if (mysql_errno(connection_) == 0) return {};
 
-    return stdx::make_unexpected(make_mysql_error_code(connection_));
+    return stdx::unexpected(make_mysql_error_code(connection_));
   }
 
   return res;
