@@ -1,16 +1,17 @@
 /*
-  Copyright (c) 2020, 2023, Oracle and/or its affiliates.
+  Copyright (c) 2020, 2024, Oracle and/or its affiliates.
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.
 
-  This program is also distributed with certain software (including
+  This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
-  separately licensed software that they have included with MySQL.
+  separately licensed software that they have either included with
+  the program or referenced in the documentation.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -31,6 +32,7 @@
 #include <string>        // string
 #include <system_error>  // error_code
 
+#include "mysqlrouter/datatypes.h"  // ServerMode
 #include "tcp_address.h"
 
 /**
@@ -80,6 +82,15 @@ class Destination {
    */
   virtual void connect_status(std::error_code /* ec */) {}
 
+  /**
+   * server-mode of the destination.
+   *
+   * may be: unavailable, read-only or read-write.
+   */
+  virtual mysqlrouter::ServerMode server_mode() const {
+    return mysqlrouter::ServerMode::Unavailable;
+  }
+
  private:
   const std::string id_;
   const std::string hostname_;
@@ -109,10 +120,12 @@ class Destinations {
   /**
    * emplace a Destination at the back of the container.
    */
+  // clang-format off
   template <class... Args>
   auto emplace_back(Args &&... args) {
     return destinations_.emplace_back(std::forward<Args>(args)...);
   }
+  // clang-format on
 
   void push_back(value_type &&v) { destinations_.push_back(std::move(v)); }
 
