@@ -1,16 +1,17 @@
 /*
-  Copyright (c) 2022, 2023, Oracle and/or its affiliates.
+  Copyright (c) 2022, 2024, Oracle and/or its affiliates.
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.
 
-  This program is also distributed with certain software (including
+  This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
-  separately licensed software that they have included with MySQL.
+  separately licensed software that they have either included with
+  the program or referenced in the documentation.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -35,7 +36,6 @@ static constexpr std::array<const char *, 48> routing_supported_options{
     "bind_address",
     "socket",
     "connect_timeout",
-    "mode",
     "routing_strategy",
     "max_connect_errors",
     "max_connections",
@@ -56,16 +56,12 @@ static constexpr std::array<const char *, 48> routing_supported_options{
     "server_ssl_cert",
     "server_ssl_key",
     "server_ssl_verify",
-    "disabled",
     "server_ssl_cipher",
     "server_ssl_ca",
     "server_ssl_capath",
     "server_ssl_crl",
     "server_ssl_crlpath",
     "server_ssl_curves",
-    // that is no longer used, kept for backward compatibilty, replaced by
-    // [destination_status].error_quarantine_interval
-    "unreachable_destination_refresh_interval",
     "connection_sharing",
     "connection_sharing_delay",
     "client_ssl_session_cache_mode",
