@@ -1,16 +1,17 @@
 /*
-  Copyright (c) 2022, 2023, Oracle and/or its affiliates.
+  Copyright (c) 2022, 2024, Oracle and/or its affiliates.
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.
 
-  This program is also distributed with certain software (including
+  This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
-  separately licensed software that they have included with MySQL.
+  separately licensed software that they have either included with
+  the program or referenced in the documentation.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -203,7 +204,6 @@ INSTANTIATE_TEST_SUITE_P(Trx, SharingAllowedTest,
 
 const SharingAllowedParam replication_source[] = {
     {"purge binary logs", Allowed::Never},             // instance
-    {"reset master", Allowed::Never},                  // instance
     {"reset binary logs and gtids ", Allowed::Never},  // instance
                                                        //
     {"set sql_log_bin = 1", Allowed::Always},          // session
@@ -213,16 +213,12 @@ INSTANTIATE_TEST_SUITE_P(ReplicationSource, SharingAllowedTest,
                          ::testing::ValuesIn(replication_source));
 
 const SharingAllowedParam replication_replica[] = {
-    {"change master to", Allowed::Never},              // instance
     {"change replication filter", Allowed::Never},     // instance
     {"change replication source to", Allowed::Never},  // instance
     {"reset replica", Allowed::Never},                 // instance
-    {"reset slave", Allowed::Never},                   // instance
     {"start replica", Allowed::Never},                 // instance
-    {"start slave", Allowed::Never},                   // instance
     {"start group_replication", Allowed::Never},       // instance
     {"stop replica", Allowed::Never},                  // instance
-    {"stop slave", Allowed::Never},                    // instance
     {"stop group_replication", Allowed::Never},        // instance
 };
 
@@ -344,8 +340,6 @@ const SharingAllowedParam show_statements[] = {
     {"SHOW function status", Allowed::Always},              //
     {"SHOW grants for user", Allowed::Always},              //
     {"SHOW index from tbl", Allowed::Always},               //
-    {"SHOW master logs", Allowed::OnlyReadWrite},           //
-    {"SHOW master status", Allowed::OnlyReadWrite},         //
     {"SHOW binary log status", Allowed::OnlyReadWrite},     //
     {"SHOW open tables", Allowed::InTransaction},           //
     {"SHOW plugins", Allowed::Always},                      //
@@ -358,8 +352,6 @@ const SharingAllowedParam show_statements[] = {
     {"SHOW profiles", Allowed::InTransaction},              //
     {"SHOW relaylog", Allowed::OnlyReadOnly},               //
     {"SHOW replicas", Allowed::OnlyReadWrite},              //
-    {"SHOW slave hosts", Allowed::OnlyReadWrite},           //
-    {"SHOW slave status", Allowed::OnlyReadOnly},           //
     {"SHOW replica status", Allowed::OnlyReadOnly},         //
     {"SHOW global status", Allowed::InTransaction},         //
     {"SHOW session status", Allowed::Always},               //
