@@ -114,6 +114,7 @@ var defaults = {
   gr_members_recovering: 0,
   gr_members_online: 3,
   current_instance_attributes: null,
+  config_defaults_stored_is_null: 0,
 };
 
 function ensure_type(options, field, expected_type) {
@@ -283,45 +284,6 @@ function get_response(stmt_key, options) {
               }),
         }
       };
-    case "router_select_metadata":
-      return {
-        stmt:
-            "SELECT F.cluster_id, F.cluster_name, R.replicaset_name, I.mysql_server_uuid, I.addresses->>'$.mysqlClassic', I.addresses->>'$.mysqlX' FROM mysql_innodb_cluster_metadata.clusters AS F JOIN mysql_innodb_cluster_metadata.replicasets AS R ON F.cluster_id = R.cluster_id JOIN mysql_innodb_cluster_metadata.instances AS I" +
-            " ON R.replicaset_id = I.replicaset_id" +
-            (options.gr_id === undefined || options.gr_id === "" ?
-                 " WHERE F.cluster_name = '" + options.innodb_cluster_name +
-                     "'" :
-                 " WHERE R.attributes->>'$.group_replication_group_name' = '" +
-                     options.gr_id + "'"),
-        result: {
-          columns: [
-            {"name": "F.cluster_id", "type": "VAR_STRING"},
-            {"name": "F.cluster_name", "type": "VAR_STRING"},
-            {"name": "R.replicaset_name", "type": "VAR_STRING"},
-            {"name": "I.mysql_server_uuid", "type": "VAR_STRING"},
-            {"name": "I.addresses->>'$.mysqlClassic'", "type": "LONGBLOB"},
-            {"name": "I.addresses->>'$.mysqlX'", "type": "LONGBLOB"}
-          ],
-          rows: options["innodb_cluster_instances"].map(function(currentValue) {
-            var xport = currentValue[3] === undefined ? 0 : currentValue[3];
-            return [
-              options.cluster_id, options.innodb_cluster_name,
-              options.innodb_cluster_replicaset_name, currentValue[0],
-              currentValue[1] + ":" + currentValue[2],
-              currentValue[1] + ":" + xport
-            ]
-          }),
-        }
-      };
-    case "router_select_metadata_account_verification":
-      return {
-        stmt:
-            "SELECT F.cluster_id, F.cluster_name, R.replicaset_name, I.mysql_server_uuid, I.addresses->>'$.mysqlClassic', I.addresses->>'$.mysqlX' FROM mysql_innodb_cluster_metadata.clusters AS F JOIN mysql_innodb_cluster_metadata.replicasets AS R ON F.cluster_id = R.cluster_id JOIN mysql_innodb_cluster_metadata.instances AS I" +
-            " ON R.replicaset_id = I.replicaset_id WHERE F.cluster_name = 'some_cluster_name'",
-        // The Router should ignore this result, it only checks if the user has
-        // rights to do it
-        result: {columns: [{"name": "1", "type": "LONG"}], rows: []}
-      };
     case "router_select_metadata_v2_gr":
       return {
         stmt:
@@ -493,55 +455,12 @@ function get_response(stmt_key, options) {
     case "router_select_router_id":
       return {
         stmt_regex:
-            "SELECT router_id FROM mysql_innodb_cluster_metadata.v2_routers WHERE router_name = .*",
+            "SELECT router_id FROM mysql_innodb_cluster_metadata.v2_routers WHERE router_name = .* and address = .*",
         result: {
           columns: [{"type": "LONG", "name": "router_id"}],
-          rows: [options.router_id]
+          rows: [[options.router_id]]
         }
       };
-    case "router_select_hosts_v1":
-      return {
-        stmt_regex:
-            "^SELECT host_id, host_name, ip_address FROM mysql_innodb_cluster_metadata.hosts WHERE host_name = '" +
-            options.bootstrap_report_host_pattern + "' LIMIT 1",
-        result: {
-          columns: [
-            {"type": "STRING", "name": "host_id"},
-            {"type": "STRING", "name": "host_name"},
-            {"type": "STRING", "name": "ip_address"}
-          ],
-          rows: options["innodb_cluster_hosts"].map(function(currentValue) {
-            var xport = currentValue[2] === undefined ? 0 : currentValue[2];
-            return [currentValue[0], currentValue[1], currentValue[2]]
-          })
-        }
-      };
-    case "router_select_hosts_join_routers_v1":
-      return {
-        stmt_regex:
-            "SELECT h.host_id, h.host_name FROM mysql_innodb_cluster_metadata.routers r JOIN mysql_innodb_cluster_metadata.hosts h    ON r.host_id = h.host_id WHERE r.router_id = .*",
-        result: {
-          columns: [
-            {"type": "STRING", "name": "host_id"},
-            {"type": "STRING", "name": "host_name"}
-          ],
-          rows: options["innodb_cluster_hosts"].map(function(currentValue) {
-            return [currentValue[0], currentValue[1]]
-          })
-        }
-      };
-    case "router_insert_into_hosts_v1":
-      return {
-        "stmt_regex":
-            "^INSERT INTO mysql_innodb_cluster_metadata.hosts        \\(host_name, location, attributes\\) VALUES \\('" +
-            options.bootstrap_report_host_pattern + "',.*",
-        "ok": {"last_insert_id": 1}
-      };
-    case "router_insert_into_routers_v1":
-      return {
-        "stmt_regex": "^INSERT INTO mysql_innodb_cluster_metadata.routers.*",
-        "ok": {"last_insert_id": 1}
-      };
     case "router_insert_into_routers":
       return {
         "stmt_regex": "^INSERT INTO mysql_innodb_cluster_metadata.v2_routers.*",
@@ -560,7 +479,8 @@ function get_response(stmt_key, options) {
     case "router_create_user":
       return {
         "stmt_regex": "^CREATE USER 'mysql_router1_[0-9a-z]{12}'@" +
-            options.user_host_pattern + " IDENTIFIED BY '.*'",
+            options.user_host_pattern +
+            " IDENTIFIED WITH `caching_sha2_password` BY '.*'",
         "ok": {}
       };
     case "router_check_auth_plugin":
@@ -601,23 +521,13 @@ function get_response(stmt_key, options) {
             options.user_host_pattern,
         "ok": {}
       };
-    case "router_update_routers_in_metadata_v1":
-      return {
-        "stmt_regex":
-            "^UPDATE mysql_innodb_cluster_metadata\\.routers SET attributes = " +
-            "JSON_SET\\(JSON_SET\\(JSON_SET\\(JSON_SET\\(JSON_SET\\(JSON_SET\\(JSON_SET\\(JSON_SET\\(IF\\(attributes IS NULL, '\\{\\}', attributes\\),    " +
-            "'\\$\\.version', '.*'\\),    '\\$\\.RWEndpoint', '.*'\\),    '\\$\\.ROEndpoint', '.*'\\),    '\\$\\.RWSplitEndpoint', '.*'\\),    '\\$\\.RWXEndpoint', '.*'\\),    " +
-            "'\\$\\.ROXEndpoint', '.*'\\),    '\\$.MetadataUser', 'mysql_router.*'\\),    '\\$.bootstrapTargetType', '.*'\\) " +
-            "WHERE router_id = .*",
-        "ok": {}
-      };
     case "router_update_routers_in_metadata":
       return {
         "stmt_regex":
             "^UPDATE mysql_innodb_cluster_metadata\\.v2_routers SET attributes = " +
-            "JSON_SET\\(JSON_SET\\(JSON_SET\\(JSON_SET\\(JSON_SET\\(JSON_SET\\(JSON_SET\\(IF\\(attributes IS NULL, '\\{\\}', attributes\\),    " +
+            "JSON_SET\\(JSON_SET\\(JSON_SET\\(JSON_SET\\(JSON_SET\\(JSON_SET\\(JSON_SET\\(JSON_SET\\(IF\\(attributes IS NULL, '\\{\\}', attributes\\),    " +
             "'\\$\\.RWEndpoint', '.*'\\),    '\\$\\.ROEndpoint', '.*'\\),    '\\$\\.RWSplitEndpoint', '.*'\\),    '\\$\\.RWXEndpoint', '.*'\\),    " +
-            "'\\$\\.ROXEndpoint', '.*'\\),    '\\$\\.MetadataUser', '.*'\\),    '\\$\\.bootstrapTargetType', '.*'\\), " +
+            "'\\$\\.ROXEndpoint', '.*'\\),    '\\$\\.MetadataUser', '.*'\\),    '\\$\\.bootstrapTargetType', '.*'\\),    '\\$\\.Configuration', CAST\\('(.*)' as JSON\\)\\), " +
             "version = '.*', cluster_id = '.*' " +
             "WHERE router_id = .*",
         "ok": {}
@@ -626,9 +536,9 @@ function get_response(stmt_key, options) {
       return {
         "stmt_regex":
             "^UPDATE mysql_innodb_cluster_metadata\\.v2_routers SET attributes = " +
-            "JSON_SET\\(JSON_SET\\(JSON_SET\\(JSON_SET\\(JSON_SET\\(JSON_SET\\(JSON_SET\\(IF\\(attributes IS NULL, '\\{\\}', attributes\\),    " +
+            "JSON_SET\\(JSON_SET\\(JSON_SET\\(JSON_SET\\(JSON_SET\\(JSON_SET\\(JSON_SET\\(JSON_SET\\(IF\\(attributes IS NULL, '\\{\\}', attributes\\),    " +
             "'\\$\\.RWEndpoint', '.*'\\),    '\\$\\.ROEndpoint', '.*'\\),    '\\$\\.RWSplitEndpoint', '.*'\\),    '\\$\\.RWXEndpoint', '.*'\\),    " +
-            "'\\$\\.ROXEndpoint', '.*'\\),    '\\$\\.MetadataUser', '.*'\\),    '\\$\\.bootstrapTargetType', '.*'\\), " +
+            "'\\$\\.ROXEndpoint', '.*'\\),    '\\$\\.MetadataUser', '.*'\\),    '\\$\\.bootstrapTargetType', '.*'\\),    '\\$\\.Configuration', CAST\\('(.*)' as JSON\\)\\), " +
             "version = '.*', clusterset_id = '.*' " +
             "WHERE router_id = .*",
         "ok": {}
@@ -698,45 +608,6 @@ function get_response(stmt_key, options) {
       };
     case "router_drop_users":
       return {stmt_regex: "^DROP USER IF EXISTS 'mysql_router.*", ok: {}};
-    case "router_select_metadata_v2":
-      return {
-        stmt:
-            "select 'default' as replicaset_name, I.mysql_server_uuid, I.endpoint, I.xendpoint, I.attributes from " +
-            "mysql_innodb_cluster_metadata.v2_instances I join " +
-            "mysql_innodb_cluster_metadata.v2_gr_clusters C on I.cluster_id = " +
-            "C.cluster_id where C.cluster_name =  " +
-            options.innodb_cluster_name + "'" +
-            (options.gr_id === undefined || options.gr_id === "" ?
-                 "" :
-                 (" AND R.attributes->>'$.group_replication_group_name' = '" +
-                  options.gr_id + "'")),
-        result: {
-          columns: [
-            {"name": "replicaset_name", "type": "VAR_STRING"},
-            {"name": "mysql_server_uuid", "type": "VAR_STRING"},
-            {"name": "I.addresses->>'$.mysqlClassic'", "type": "LONGBLOB"},
-            {"name": "I.addresses->>'$.mysqlX'", "type": "LONGBLOB"},
-            {"name": "I.attributes", "type": "VAR_STRING"}
-          ],
-          rows: options["innodb_cluster_instances"].map(function(currentValue) {
-            var xport = currentValue[3] === undefined ? 0 : currentValue[3];
-            var attributes =
-                currentValue[4] === undefined ? "" : currentValue[4];
-            return [
-              options.innodb_cluster_replicaset_name, currentValue[0],
-              currentValue[1] + ":" + currentValue[2],
-              currentValue[1] + ":" + xport, attributes
-            ]
-          }),
-        }
-      };
-    case "router_count_clusters_v1":
-      return {
-        stmt: "select count(*) from " +
-            "mysql_innodb_cluster_metadata.clusters",
-        result:
-            {columns: [{"type": "LONGLONG", "name": "count(*)"}], rows: [[1]]}
-      };
     case "router_count_clusters_v2":
       return {
         stmt: "select count(*) from " +
@@ -773,41 +644,6 @@ function get_response(stmt_key, options) {
           "rows": [["Mysqlx_ssl_cipher", mysqld.session.mysqlx_ssl_cipher]]
         }
       };
-    case "router_select_cluster_instances_v1":
-      return {
-        "stmt":
-            "SELECT F.cluster_id, R.attributes->>'$.group_replication_group_name' as uuid, F.cluster_name, " +
-            "JSON_UNQUOTE(JSON_EXTRACT(I.addresses, '$.mysqlClassic')), '' as attributes " +
-            "FROM " +
-            "mysql_innodb_cluster_metadata.clusters AS F, " +
-            "mysql_innodb_cluster_metadata.instances AS I, " +
-            "mysql_innodb_cluster_metadata.replicasets AS R " +
-            "WHERE R.replicaset_id = (SELECT replicaset_id FROM mysql_innodb_cluster_metadata.instances " +
-            "WHERE CAST(mysql_server_uuid AS char ascii) = CAST(@@server_uuid AS char ascii)) AND I.replicaset_id = R.replicaset_id " +
-            "AND R.cluster_id = F.cluster_id",
-        result: {
-          columns: [
-            {"type": "STRING", "name": "cluster_id"},
-            {"type": "STRING", "name": "uuid"},
-            {"type": "STRING", "name": "cluster_name"},
-            {
-              "type": "STRING",
-              "name":
-                  "JSON_UNQUOTE(JSON_EXTRACT(I.addresses, '$.mysqlClassic'))"
-            },
-            {"type": "STRING", "name": "attributes"},
-          ],
-          rows: options["innodb_cluster_instances"].map(function(currentValue) {
-            return [
-              options.cluster_id,
-              options.gr_id,
-              options.innodb_cluster_name,
-              currentValue[1] + ":" + currentValue[2],
-              "",
-            ]
-          })
-        }
-      };
     case "router_select_cluster_instances_v2_ar":
       return {
         "stmt":
@@ -894,7 +730,8 @@ function get_response(stmt_key, options) {
       return {
         "stmt_regex": "^CREATE USER IF NOT EXISTS '" +
             options.account_user_pattern + "'@'" +
-            options.account_host_pattern + "' IDENTIFIED BY '" +
+            options.account_host_pattern +
+            "' IDENTIFIED WITH `caching_sha2_password` BY '" +
             options.account_pass_pattern + "'",
         "ok": {warning_count: options.create_user_warning_count}
       };
@@ -903,7 +740,8 @@ function get_response(stmt_key, options) {
         // CREATE USER (without IF NOT EXISTS) is triggered by
         // --account-create always
         "stmt_regex": "^CREATE USER '" + options.account_user_pattern + "'@'" +
-            options.account_host_pattern + "' IDENTIFIED BY '" +
+            options.account_host_pattern +
+            "' IDENTIFIED WITH `caching_sha2_password` BY '" +
             options.account_pass_pattern + "'",
         "ok": {}
       };
@@ -916,33 +754,6 @@ function get_response(stmt_key, options) {
           "rows": [[options.cluster_id]]
         }
       };
-    case "router_update_attributes_v1":
-      return {
-        "stmt_regex": "UPDATE mysql_innodb_cluster_metadata\\.routers" +
-            " SET attributes = JSON_SET\\(JSON_SET\\(JSON_SET\\(JSON_SET\\(JSON_SET\\(JSON_SET\\(JSON_SET\\(" +
-            " IF\\(attributes IS NULL, '\\{\\}', attributes\\), '\\$\\.version', '.*'\\)," +
-            " '\\$\\.RWEndpoint', '.*'\\), '\\$\\.ROEndpoint', '.*'\\), '\\$\\.RWSplitEndpoint', '.*'\\), '\\$\\.RWXEndpoint', '.*'\\)," +
-            " '\\$\\.ROXEndpoint', '.*'\\), '\\$\\.MetadataUser', '.*'\\) WHERE router_id = " +
-            options.router_id,
-        "ok": {}
-      };
-    case "router_update_attributes_strict_v1":
-      // the exact match, not regex
-      return {
-        "stmt": "UPDATE mysql_innodb_cluster_metadata.routers" +
-            " SET attributes = JSON_SET(JSON_SET(JSON_SET(JSON_SET(JSON_SET(JSON_SET(JSON_SET(" +
-            " IF(attributes IS NULL, '{}', attributes)," +
-            " '$.version', '" + options.router_version +
-            "'), '$.RWEndpoint', '" + options.router_rw_classic_port +
-            "'), '$.ROEndpoint', '" + options.router_ro_classic_port +
-            "'), '$.RWSplitEndpoint', '" +
-            options.router_rw_split_classic_port + "'), '$.RWXEndpoint', '" +
-            options.router_rw_x_port + "'), '$.ROXEndpoint', '" +
-            options.router_ro_x_port + "'), '$.MetadataUser', '" +
-            options.router_metadata_user +
-            "') WHERE router_id = " + options.router_id,
-        "ok": {}
-      };
     case "router_create_user_show_warnings":
       // this query will only be issued if CREATE USER [IF NOT EXISTS]
       // returned warning_count > 0
@@ -966,27 +777,10 @@ function get_response(stmt_key, options) {
     case "router_update_attributes_v2":
       return {
         "stmt_regex": "UPDATE mysql_innodb_cluster_metadata\\.v2_routers" +
-            " SET version = .*, last_check_in = NOW\\(\\), attributes = JSON_SET\\(JSON_SET\\(JSON_SET\\(JSON_SET\\(JSON_SET\\(JSON_SET\\(" +
+            " SET version = '(.*)', last_check_in = NOW\\(\\), attributes = JSON_SET\\(JSON_SET\\(JSON_SET\\(JSON_SET\\(JSON_SET\\(JSON_SET\\(JSON_SET\\(" +
             " IF\\(attributes IS NULL, '\\{\\}', attributes\\)," +
-            " '\\$\\.RWEndpoint', '.*'\\), '\\$\\.ROEndpoint', '.*'\\), '\\$\\.RWSplitEndpoint', '.*'\\), '\\$\\.RWXEndpoint', '.*'\\)," +
-            " '\\$\\.ROXEndpoint', '.*'\\), '\\$\\.MetadataUser', '.*'\\) WHERE router_id = .*",
-        "ok": {}
-      };
-    case "router_update_attributes_strict_v2":
-      return {
-        "stmt": "UPDATE mysql_innodb_cluster_metadata.v2_routers" +
-            " SET version = '" + options.router_version +
-            "', last_check_in = NOW()" +
-            ", attributes = JSON_SET(JSON_SET(JSON_SET(JSON_SET(JSON_SET(JSON_SET(" +
-            " IF(attributes IS NULL, '{}', attributes)," +
-            " '$.RWEndpoint', '" + options.router_rw_classic_port +
-            "'), '$.ROEndpoint', '" + options.router_ro_classic_port +
-            "'), '$.RWSplitEndpoint', '" +
-            options.router_rw_split_classic_port + "'), '$.RWXEndpoint', '" +
-            options.router_rw_x_port + "'), '$.ROXEndpoint', '" +
-            options.router_ro_x_port + "'), '$.MetadataUser', '" +
-            options.router_metadata_user +
-            "') WHERE router_id = " + options.router_id,
+            " '\\$\\.RWEndpoint', '(.*)'\\), '\\$\\.ROEndpoint', '(.*)'\\), '\\$\\.RWSplitEndpoint', '(.*)'\\), '\\$\\.RWXEndpoint', '(.*)'\\)," +
+            " '\\$\\.ROXEndpoint', '(.*)'\\), '\\$\\.MetadataUser', '(.*)'\\), '\\$.Configuration', CAST\\('(.*)' as JSON\\)\\) WHERE router_id = (.*)",
         "ok": {}
       };
     case "router_update_last_check_in_v2":
@@ -1453,6 +1247,72 @@ function get_response(stmt_key, options) {
           rows: [[options.current_instance_attributes]]
         }
       };
+    case "router_select_config_defaults_stored_gr_cluster":
+      return {
+        stmt_regex:
+            "select JSON_EXTRACT\\(router_options, '\\$\\.Configuration.\"" +
+            options["router_version"] +
+            "\"'\\) IS NULL from mysql_innodb_cluster_metadata.v2_gr_clusters where cluster_id = '.*'",
+        result: {
+          columns: [{
+            "type": "LONGLONG",
+            "name": "JSON_EXTRACT(router_options, '$.Configuration\"') IS NULL"
+          }],
+          rows: [[options.config_defaults_stored_is_null]]
+        }
+      };
+    case "router_select_config_defaults_stored_ar_cluster":
+      return {
+        stmt_regex:
+            "select JSON_EXTRACT\\(router_options, '\\$\\.Configuration.\"" +
+            options["router_version"] +
+            "\"'\\) IS NULL from mysql_innodb_cluster_metadata.v2_ar_clusters where cluster_id = '.*'",
+        result: {
+          columns: [{
+            "type": "LONGLONG",
+            "name": "JSON_EXTRACT(router_options, '$.Configuration') IS NULL"
+          }],
+          rows: [[options.config_defaults_stored_is_null]]
+        }
+      };
+    case "router_select_config_defaults_stored_clusterset":
+      return {
+        stmt_regex:
+            "select JSON_EXTRACT\\(router_options, '\\$\\.Configuration.\"" +
+            options["router_version"] +
+            "\"'\\) IS NULL from mysql_innodb_cluster_metadata.v2_cs_clustersets where clusterset_id = '.*'",
+        result: {
+          columns: [{
+            "type": "LONGLONG",
+            "name": "JSON_EXTRACT(router_options, '$.Configuration') IS NULL"
+          }],
+          rows: [[options.config_defaults_stored_is_null]]
+        }
+      };
+    case "router_store_config_defaults_gr_cluster":
+      return {
+        stmt_regex:
+            "UPDATE mysql_innodb_cluster_metadata\\.v2_gr_clusters SET router_options = " +
+            "JSON_MERGE_PATCH\\(IF\\(router_options IS NULL, '\\{\\}', router_options\\), " +
+            "CAST\\('(.*)' as JSON\\)\\) WHERE cluster_id = '.*'",
+        ok: {}
+      };
+    case "router_store_config_defaults_ar_cluster":
+      return {
+        stmt_regex:
+            "UPDATE mysql_innodb_cluster_metadata\\.v2_ar_clusters SET router_options = " +
+            "JSON_MERGE_PATCH\\(IF\\(router_options IS NULL, '\\{\\}', router_options\\), " +
+            "CAST\\('(.*)' as JSON\\)\\) WHERE cluster_id = '.*'",
+        ok: {}
+      };
+    case "router_store_config_defaults_clusterset":
+      return {
+        stmt_regex:
+            "UPDATE mysql_innodb_cluster_metadata\\.v2_cs_clustersets SET router_options = " +
+            "JSON_MERGE_PATCH\\(IF\\(router_options IS NULL, '\\{\\}', router_options\\), " +
+            "CAST\\('(.*)' as JSON\\)\\) WHERE clusterset_id = '.*'",
+        ok: {}
+      };
   };
 };
 
@@ -1533,7 +1393,7 @@ exports.unknown_statement_response = function(stmt) {
  * @param {string} regex_stmt regex statement text
  * @param {object} common_responses_regex object containing
  *     common responses
- * @returns  response if any matches the statmenet or undefined
+ * @returns  response if any matches the statement or undefined
  */
 exports.handle_regex_stmt = function(regex_stmt, common_responses_regex) {
   for (var stmt in common_responses_regex) {
