@@ -1,16 +1,17 @@
 /*
-Copyright (c) 2019, 2023, Oracle and/or its affiliates.
+Copyright (c) 2019, 2024, Oracle and/or its affiliates.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License, version 2.0,
 as published by the Free Software Foundation.
 
-This program is also distributed with certain software (including
+This program is designed to work with certain software (including
 but not limited to OpenSSL) that is licensed under separate terms,
 as designated in a particular file or component or in included license
 documentation.  The authors of MySQL hereby grant you an additional
 permission to link the program and your derivative works with the
-separately licensed software that they have included with MySQL.
+separately licensed software that they have either included with
+the program or referenced in the documentation.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -78,7 +79,6 @@ class AsyncReplicasetTest : public RouterComponentTest {
   }
 
   std::string get_metadata_cache_section(
-      uint16_t metadata_server_port = 0,
       const std::chrono::milliseconds ttl = kTTL,
       const std::string &cluster_type_str = "rs") {
     auto ttl_str = std::to_string(std::chrono::duration<double>(ttl).count());
@@ -87,11 +87,7 @@ class AsyncReplicasetTest : public RouterComponentTest {
            "cluster_type=" +
            cluster_type_str +
            "\n"
-           "router_id=1\n" +
-           ((metadata_server_port == 0)
-                ? ""
-                : "bootstrap_server_addresses=mysql://localhost:" +
-                      std::to_string(metadata_server_port) + "\n") +
+           "router_id=1\n"
            "user=mysql_router1_user\n"
            "metadata_cluster=test\n"
            "connect_timeout=1\n"
@@ -246,8 +242,7 @@ TEST_F(AsyncReplicasetTest, NoChange) {
       "// Create a configuration file sections with low ttl so that any "
       "changes we make in the mock server via http port were refreshed "
       "quickly");
-  const std::string metadata_cache_section =
-      get_metadata_cache_section(0, kTTL);
+  const std::string metadata_cache_section = get_metadata_cache_section(kTTL);
   const uint16_t router_port = port_pool_.get_next_available();
   const std::string routing_section = get_metadata_cache_routing_section(
       router_port, "PRIMARY", "first-available");
@@ -309,8 +304,7 @@ TEST_F(AsyncReplicasetTest, SecondaryAdded) {
       "// Create a configuration file sections with low ttl so that any "
       "changes we make in the mock server via http port were refreshed "
       "quickly");
-  const std::string metadata_cache_section =
-      get_metadata_cache_section(0, kTTL);
+  const std::string metadata_cache_section = get_metadata_cache_section(kTTL);
   const uint16_t router_port = port_pool_.get_next_available();
   const std::string routing_section_rw = get_metadata_cache_routing_section(
       router_port, "PRIMARY", "first-available");
@@ -398,8 +392,7 @@ TEST_F(AsyncReplicasetTest, SecondaryRemovedStillReachable) {
       "// Create a configuration file sections with low ttl so that any "
       "changes we make in the mock server via http port were refreshed "
       "quickly");
-  const std::string metadata_cache_section =
-      get_metadata_cache_section(0, kTTL);
+  const std::string metadata_cache_section = get_metadata_cache_section(kTTL);
   const uint16_t router_port_rw = port_pool_.get_next_available();
   const std::string routing_section_rw = get_metadata_cache_routing_section(
       router_port_rw, "PRIMARY", "first-available");
@@ -489,8 +482,7 @@ TEST_F(AsyncReplicasetTest, ClusterIdChanged) {
       "// Create a configuration file sections with low ttl so that any "
       "changes we make in the mock server via http port were refreshed "
       "quickly");
-  const std::string metadata_cache_section =
-      get_metadata_cache_section(0, kTTL);
+  const std::string metadata_cache_section = get_metadata_cache_section(kTTL);
   const uint16_t router_port_rw = port_pool_.get_next_available();
   const std::string routing_section_rw = get_metadata_cache_routing_section(
       router_port_rw, "PRIMARY", "first-available");
@@ -568,8 +560,7 @@ TEST_F(AsyncReplicasetTest, ClusterSecondaryQueryErrors) {
       "// Create a configuration file sections with low ttl so that any "
       "changes we make in the mock server via http port were refreshed "
       "quickly");
-  const std::string metadata_cache_section =
-      get_metadata_cache_section(0, kTTL);
+  const std::string metadata_cache_section = get_metadata_cache_section(kTTL);
   const uint16_t router_port_rw = port_pool_.get_next_available();
   const std::string routing_section_rw = get_metadata_cache_routing_section(
       router_port_rw, "PRIMARY", "first-available");
@@ -641,8 +632,7 @@ TEST_F(AsyncReplicasetTest, MetadataUnavailableDisconnectFromSecondary) {
   SCOPED_TRACE(
       "// Create a configuration file. disconnect_on_metadata_unavailable for "
       "R/W routing is false, for RO routing is true");
-  const std::string metadata_cache_section =
-      get_metadata_cache_section(0, kTTL);
+  const std::string metadata_cache_section = get_metadata_cache_section(kTTL);
   const uint16_t router_port_rw = port_pool_.get_next_available();
   const std::string routing_section_rw = get_metadata_cache_routing_section(
       router_port_rw, "PRIMARY", "first-available",
@@ -727,8 +717,7 @@ TEST_F(AsyncReplicasetTest, MetadataUnavailableDisconnectFromPrimary) {
   SCOPED_TRACE(
       "// Create a configuration file. disconnect_on_metadata_unavailable for "
       "R/W routing is true, for RO routing is false");
-  const std::string metadata_cache_section =
-      get_metadata_cache_section(0, kTTL);
+  const std::string metadata_cache_section = get_metadata_cache_section(kTTL);
   const uint16_t router_port_rw = port_pool_.get_next_available();
   const std::string routing_section_rw = get_metadata_cache_routing_section(
       router_port_rw, "PRIMARY", "first-available",
@@ -829,8 +818,7 @@ TEST_F(AsyncReplicasetTest, MultipleChangesInTheCluster) {
                             cluster_id, "", initial_cluster_members, view_id));
 
   SCOPED_TRACE("// Create a configuration file.");
-  const std::string metadata_cache_section =
-      get_metadata_cache_section(0, kTTL);
+  const std::string metadata_cache_section = get_metadata_cache_section(kTTL);
   const uint16_t router_port_rw = port_pool_.get_next_available();
   const std::string routing_section_rw = get_metadata_cache_routing_section(
       router_port_rw, "PRIMARY", "first-available");
@@ -907,8 +895,7 @@ TEST_F(AsyncReplicasetTest, SecondaryRemoved) {
       create_state_file_content(cluster_id, "", cluster_nodes_ports, view_id));
 
   SCOPED_TRACE("// Create a configuration file.");
-  const std::string metadata_cache_section =
-      get_metadata_cache_section(0, kTTL);
+  const std::string metadata_cache_section = get_metadata_cache_section(kTTL);
   const uint16_t router_port_rw = port_pool_.get_next_available();
   const std::string routing_section_rw = get_metadata_cache_routing_section(
       router_port_rw, "PRIMARY", "first-available");
@@ -996,8 +983,7 @@ TEST_F(AsyncReplicasetTest, NewPrimaryOldGone) {
                             cluster_id, "", initial_cluster_members, view_id));
 
   SCOPED_TRACE("// Create a configuration file.");
-  const std::string metadata_cache_section =
-      get_metadata_cache_section(0, kTTL);
+  const std::string metadata_cache_section = get_metadata_cache_section(kTTL);
   const uint16_t router_port_rw = port_pool_.get_next_available();
   const std::string routing_section_rw = get_metadata_cache_routing_section(
       router_port_rw, "PRIMARY", "first-available");
@@ -1081,8 +1067,7 @@ TEST_F(AsyncReplicasetTest, NewPrimaryOldBecomesSecondary) {
       create_state_file_content(cluster_id, "", cluster_nodes_ports, view_id));
 
   SCOPED_TRACE("// Create a configuration file.");
-  const std::string metadata_cache_section =
-      get_metadata_cache_section(0, kTTL);
+  const std::string metadata_cache_section = get_metadata_cache_section(kTTL);
   const uint16_t router_port_rw = port_pool_.get_next_available();
   const std::string routing_section_rw = get_metadata_cache_routing_section(
       router_port_rw, "PRIMARY", "first-available");
@@ -1159,8 +1144,7 @@ TEST_F(AsyncReplicasetTest, NewPrimaryOldBecomesSecondaryDisconnectOnPromoted) {
       create_state_file_content(cluster_id, "", cluster_nodes_ports, view_id));
 
   SCOPED_TRACE("// Create a configuration file.");
-  const std::string metadata_cache_section =
-      get_metadata_cache_section(0, kTTL);
+  const std::string metadata_cache_section = get_metadata_cache_section(kTTL);
   const uint16_t router_port_rw = port_pool_.get_next_available();
   const std::string routing_section_rw = get_metadata_cache_routing_section(
       router_port_rw, "PRIMARY", "first-available");
@@ -1245,8 +1229,7 @@ TEST_F(AsyncReplicasetTest, OnlyPrimaryLeftAcceptsRWAndRO) {
       create_state_file_content(cluster_id, "", cluster_nodes_ports, view_id));
 
   SCOPED_TRACE("// Create a configuration file.");
-  const std::string metadata_cache_section =
-      get_metadata_cache_section(0, kTTL);
+  const std::string metadata_cache_section = get_metadata_cache_section(kTTL);
   const uint16_t router_port_rw = port_pool_.get_next_available();
   const std::string routing_section_rw = get_metadata_cache_routing_section(
       router_port_rw, "PRIMARY", "first-available");
@@ -1328,8 +1311,7 @@ TEST_F(AsyncReplicasetTest, OnlyPrimaryLeftAcceptsRW) {
       create_state_file_content(cluster_id, "", cluster_nodes_ports, view_id));
 
   SCOPED_TRACE("// Create a configuration file.");
-  const std::string metadata_cache_section =
-      get_metadata_cache_section(0, kTTL);
+  const std::string metadata_cache_section = get_metadata_cache_section(kTTL);
   const uint16_t router_port_rw = port_pool_.get_next_available();
   const std::string routing_section_rw = get_metadata_cache_routing_section(
       router_port_rw, "PRIMARY", "first-available");
@@ -1409,8 +1391,7 @@ TEST_P(NodeUnavailableTest, NodeUnavailable) {
       create_state_file_content(cluster_id, "", cluster_nodes_ports, view_id));
 
   SCOPED_TRACE("// Create a configuration file.");
-  const std::string metadata_cache_section =
-      get_metadata_cache_section(0, kTTL);
+  const std::string metadata_cache_section = get_metadata_cache_section(kTTL);
   const uint16_t router_port_rw = port_pool_.get_next_available();
   const std::string routing_section_rw = get_metadata_cache_routing_section(
       router_port_rw, "PRIMARY", "first-available");
@@ -1517,8 +1498,7 @@ TEST_P(NodeUnavailableAllNodesDownTest, NodeUnavailableAllNodesDown) {
       create_state_file_content(cluster_id, "", cluster_nodes_ports, view_id));
 
   SCOPED_TRACE("// Create a configuration file.");
-  const std::string metadata_cache_section =
-      get_metadata_cache_section(0, kTTL);
+  const std::string metadata_cache_section = get_metadata_cache_section(kTTL);
   const uint16_t router_port_rw = port_pool_.get_next_available();
   const std::string routing_section_rw = get_metadata_cache_routing_section(
       router_port_rw, "PRIMARY", "first-available");
@@ -1601,7 +1581,7 @@ TEST_P(ClusterTypeMismatchTest, ClusterTypeMismatch) {
 
   SCOPED_TRACE("// Create a configuration file.");
   const std::string metadata_cache_section =
-      get_metadata_cache_section(0, kTTL, GetParam().cluster_type_str);
+      get_metadata_cache_section(kTTL, GetParam().cluster_type_str);
   const uint16_t router_port_rw = port_pool_.get_next_available();
   const std::string routing_section_rw = get_metadata_cache_routing_section(
       router_port_rw, "PRIMARY", "first-available");
@@ -1679,7 +1659,7 @@ TEST_P(UnexpectedResultFromMDRefreshTest, UnexpectedResultFromMDRefreshQuery) {
       "// Create a configuration file. disconnect_on_metadata_unavailable for "
       "R/W  and R/O routing is true");
   const std::string metadata_cache_section =
-      get_metadata_cache_section(0, kTTL, GetParam().cluster_type_str);
+      get_metadata_cache_section(kTTL, GetParam().cluster_type_str);
   const uint16_t router_port_rw = port_pool_.get_next_available();
   const std::string routing_section_rw = get_metadata_cache_routing_section(
       router_port_rw, "PRIMARY", "first-available",
