@@ -1,16 +1,17 @@
 /*
-  Copyright (c) 2017, 2023, Oracle and/or its affiliates.
+  Copyright (c) 2017, 2024, Oracle and/or its affiliates.
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.
 
-  This program is also distributed with certain software (including
+  This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
-  separately licensed software that they have included with MySQL.
+  separately licensed software that they have either included with
+  the program or referenced in the documentation.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -30,6 +31,7 @@
 #include "filesystem_utils.h"
 #include "mock_server_testutils.h"
 #include "random_generator.h"
+#include "router_component_testutils.h"
 
 using namespace std::chrono_literals;
 using namespace std::string_literals;
@@ -87,6 +89,17 @@ bool RouterComponentTest::wait_log_contains(const ProcessWrapper &router,
   return found;
 }
 
+void RouterComponentTest::check_log_contains(
+    const ProcessWrapper &router, const std::string &expected_string,
+    size_t expected_occurences /*=1*/) {
+  const std::string log_content = router.get_logfile_content();
+  ASSERT_EQ(expected_occurences,
+            count_str_occurences(log_content, expected_string))
+      << "Expected: " << expected_string << "\n"
+      << "in:\n"
+      << log_content;
+}
+
 constexpr const char RouterComponentBootstrapTest::kRootPassword[];
 
 const RouterComponentBootstrapTest::OutputResponder
@@ -117,11 +130,14 @@ void RouterComponentBootstrapTest::bootstrap_failover(
     const std::vector<std::string> &extra_router_options) {
   std::string cluster_name("mycluster");
 
-  std::vector<std::pair<std::string, unsigned>> gr_members;
+  std::vector<uint16_t> classic_ports;
   for (const auto &mock_server_config : mock_server_configs) {
-    gr_members.emplace_back(mock_server_config.ip, mock_server_config.port);
+    classic_ports.emplace_back(mock_server_config.port);
   }
 
+  const auto cluster_nodes = classic_ports_to_cluster_nodes(classic_ports);
+  const auto gr_nodes = classic_ports_to_gr_nodes(classic_ports);
+
   std::vector<std::tuple<ProcessWrapper &, unsigned int>> mock_servers;
 
   // shutdown the mock-servers when bootstrap is done.
@@ -150,9 +166,9 @@ void RouterComponentBootstrapTest::bootstrap_failover(
         launch_mysql_server_mock(mock_server_config.js_filename, port,
                                  EXIT_SUCCESS, false, http_port),
         port);
-    set_mock_bootstrap_data(http_port, cluster_name, gr_members,
-                            metadata_version,
-                            mock_server_config.cluster_specific_id);
+    set_mock_metadata(http_port, mock_server_config.cluster_specific_id,
+                      gr_nodes, 0, cluster_nodes, 0, false, "127.0.0.1", "",
+                      metadata_version, cluster_name);
   }
 
   std::vector<std::string> router_cmdline;
@@ -160,8 +176,8 @@ void RouterComponentBootstrapTest::bootstrap_failover(
   if (router_options.size()) {
     router_cmdline = router_options;
   } else {
-    router_cmdline.emplace_back("--bootstrap=" + gr_members[0].first + ":" +
-                                std::to_string(gr_members[0].second));
+    router_cmdline.emplace_back("--bootstrap=127.0.0.1:" +
+                                std::to_string(cluster_nodes[0].classic_port));
 
     router_cmdline.emplace_back("--connect-timeout");
     router_cmdline.emplace_back("1");
