@@ -1,15 +1,16 @@
-/* Copyright (c) 2015, 2022, Oracle and/or its affiliates.
+/* Copyright (c) 2015, 2024, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
    as published by the Free Software Foundation.
 
-   This program is also distributed with certain software (including
+   This program is designed to work with certain software (including
    but not limited to OpenSSL) that is licensed under separate terms,
    as designated in a particular file or component or in included license
    documentation.  The authors of MySQL hereby grant you an additional
    permission to link the program and your derivative works with the
-   separately licensed software that they have included with MySQL.
+   separately licensed software that they have either included with
+   the program or referenced in the documentation.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -223,6 +224,8 @@ my_svc_bool security_context_lookup(MYSQL_SECURITY_CONTEXT ctx,
   0 otherwise
   - privilege_execute my_svc_bool *  1 if the user account has execute
   privilege, 0 otherwise
+  - is_skip_grants_user bool      *  true if user account has skip-grants
+  privilege, false otherwise
 
   @param[in]  ctx   The handle of the security context to read from
   @param[in]  name  The option name to read
@@ -254,11 +257,13 @@ my_svc_bool security_context_get_option(MYSQL_SECURITY_CONTEXT ctx,
       } else if (!strcmp(name, "external_user")) {
         *((MYSQL_LEX_CSTRING *)inout_pvalue) = ctx->external_user();
       } else if (!strcmp(name, "privilege_super")) {
-        bool checked = ctx->check_access(SUPER_ACL);
+        const bool checked = ctx->check_access(SUPER_ACL);
         *((my_svc_bool *)inout_pvalue) = checked ? MY_SVC_TRUE : MY_SVC_FALSE;
       } else if (!strcmp(name, "privilege_execute")) {
-        bool checked = ctx->check_access(EXECUTE_ACL);
+        const bool checked = ctx->check_access(EXECUTE_ACL);
         *((my_svc_bool *)inout_pvalue) = checked ? MY_SVC_TRUE : MY_SVC_FALSE;
+      } else if (!strcmp(name, "is_skip_grants_user")) {
+        *((bool *)inout_pvalue) = ctx->is_skip_grants_user();
       } else
         return MY_SVC_TRUE; /* invalid option */
     }
@@ -318,14 +323,14 @@ my_svc_bool security_context_set_option(MYSQL_SECURITY_CONTEXT ctx,
       LEX_CSTRING *value = (LEX_CSTRING *)pvalue;
       ctx->assign_proxy_user(value->str, value->length);
     } else if (!strcmp(name, "privilege_super")) {
-      my_svc_bool value = *(my_svc_bool *)pvalue;
+      const my_svc_bool value = *(my_svc_bool *)pvalue;
       if (value)
         ctx->set_master_access(ctx->master_access() | (SUPER_ACL));
       else
         ctx->set_master_access(ctx->master_access() & ~(SUPER_ACL));
 
     } else if (!strcmp(name, "privilege_execute")) {
-      my_svc_bool value = *(my_svc_bool *)pvalue;
+      const my_svc_bool value = *(my_svc_bool *)pvalue;
       if (value)
         ctx->set_master_access(ctx->master_access() | (EXECUTE_ACL));
       else
