@@ -1,15 +1,16 @@
-/* Copyright (c) 2018, 2023, Oracle and/or its affiliates.
+/* Copyright (c) 2018, 2024, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
    as published by the Free Software Foundation.
 
-   This program is also distributed with certain software (including
+   This program is designed to work with certain software (including
    but not limited to OpenSSL) that is licensed under separate terms,
    as designated in a particular file or component or in included license
    documentation.  The authors of MySQL hereby grant you an additional
    permission to link the program and your derivative works with the
-   separately licensed software that they have included with MySQL.
+   separately licensed software that they have either included with
+   the program or referenced in the documentation.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -47,7 +48,7 @@ static void debug_corrupt_event(unsigned char *buffer, unsigned int event_len) {
     Previous_gtids_log_event and Gtid_log_event
     events from injected corruption to allow dump thread to move forward
     on binary log until the missing transactions from slave when
-    MASTER_AUTO_POSITION= 1.
+    SOURCE_AUTO_POSITION= 1.
   */
   DBUG_EXECUTE_IF(
       "corrupt_read_log_event", unsigned char type = buffer[EVENT_TYPE_OFFSET];
@@ -249,18 +250,6 @@ Binlog_read_error::Error_type binlog_event_deserialize(
     case mysql::binlog::event::FORMAT_DESCRIPTION_EVENT:
       ev = new Format_description_log_event(buf, fde);
       break;
-    case mysql::binlog::event::WRITE_ROWS_EVENT_V1:
-      if (!(fde->post_header_len.empty()))
-        ev = new Write_rows_log_event(buf, fde);
-      break;
-    case mysql::binlog::event::UPDATE_ROWS_EVENT_V1:
-      if (!(fde->post_header_len.empty()))
-        ev = new Update_rows_log_event(buf, fde);
-      break;
-    case mysql::binlog::event::DELETE_ROWS_EVENT_V1:
-      if (!(fde->post_header_len.empty()))
-        ev = new Delete_rows_log_event(buf, fde);
-      break;
     case mysql::binlog::event::TABLE_MAP_EVENT:
       if (!(fde->post_header_len.empty()))
         ev = new Table_map_log_event(buf, fde);
