@@ -1,15 +1,16 @@
-/* Copyright (c) 2018, 2023, Oracle and/or its affiliates.
+/* Copyright (c) 2018, 2024, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
    as published by the Free Software Foundation.
 
-   This program is also distributed with certain software (including
+   This program is designed to work with certain software (including
    but not limited to OpenSSL) that is licensed under separate terms,
    as designated in a particular file or component or in included license
    documentation.  The authors of MySQL hereby grant you an additional
    permission to link the program and your derivative works with the
-   separately licensed software that they have included with MySQL.
+   separately licensed software that they have either included with
+   the program or referenced in the documentation.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -435,7 +436,6 @@ bool Create_field::init(
       break;
     case MYSQL_TYPE_FLOAT:
       /* change FLOAT(precision) to FLOAT or DOUBLE */
-      allowed_type_modifier = AUTO_INCREMENT_FLAG;
       if (display_width_in_codepoints && !fld_decimals) {
         const size_t tmp_length = m_max_display_width_in_codepoints;
         if (tmp_length > PRECISION_FOR_DOUBLE) {
@@ -460,7 +460,6 @@ bool Create_field::init(
       }
       break;
     case MYSQL_TYPE_DOUBLE:
-      allowed_type_modifier = AUTO_INCREMENT_FLAG;
       if (!display_width_in_codepoints && !fld_decimals) {
         m_max_display_width_in_codepoints = DBL_DIG + 7;
         decimals = DECIMAL_NOT_SPECIFIED;
