@@ -1,15 +1,16 @@
-/* Copyright (c) 2020, 2023, Oracle and/or its affiliates.
+/* Copyright (c) 2020, 2024, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
    as published by the Free Software Foundation.
 
-   This program is also distributed with certain software (including
+   This program is designed to work with certain software (including
    but not limited to OpenSSL) that is licensed under separate terms,
    as designated in a particular file or component or in included license
    documentation.  The authors of MySQL hereby grant you an additional
    permission to link the program and your derivative works with the
-   separately licensed software that they have included with MySQL.
+   separately licensed software that they have either included with
+   the program or referenced in the documentation.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -116,53 +117,137 @@ inline FilterCost EstimateFilterCost(
 
 double EstimateCostForRefAccess(THD *thd, TABLE *table, unsigned key_idx,
                                 double num_output_rows);
-void EstimateSortCost(AccessPath *path);
+
+/**
+  Estimate costs and output rows for a SORT AccessPath.
+  @param thd Current thread.
+  @param path the AccessPath.
+  @param distinct_rows An estimate of the number of distinct rows, if
+     remove_duplicates==true and we have an estimate already.
+*/
+void EstimateSortCost(THD *thd, AccessPath *path,
+                      double distinct_rows = kUnknownRowCount);
+
 void EstimateMaterializeCost(THD *thd, AccessPath *path);
 
+/**
+   Estimate the number of rows with a distinct combination of values for
+   'terms'. @see EstimateDistinctRowsFromStatistics for additional details.
+   @param thd The current thread.
+   @param child_rows The number of input rows.
+   @param terms The terms for which we estimate the number of unique
+                combinations.
+   @returns The estimated number of output rows.
+*/
+double EstimateDistinctRows(THD *thd, double child_rows,
+                            Bounds_checked_array<const Item *const> terms);
 /**
    Estimate costs and result row count for an aggregate operation.
+   @param[in,out] thd The current thread.
    @param[in,out] path The AGGREGATE path.
    @param[in] query_block The Query_block to which 'path' belongs.
-   @param[in,out] trace Optimizer trace text.
  */
-void EstimateAggregateCost(AccessPath *path, const Query_block *query_block,
-                           std::string *trace = nullptr);
+void EstimateAggregateCost(THD *thd, AccessPath *path,
+                           const Query_block *query_block);
 void EstimateDeleteRowsCost(AccessPath *path);
 void EstimateUpdateRowsCost(AccessPath *path);
 
 /// Estimate the costs and row count for a STREAM AccessPath.
 void EstimateStreamCost(AccessPath *path);
 
-/// Estimate the costs and row count for a LIMIT_OFFSET AccessPath.
+/**
+   Estimate the costs and row count for a WINDOW AccessPath. As described in
+   @see AccessPath::m_init_cost, the cost to read k out of N rows would be
+   init_cost + (k/N) * (cost - init_cost).
+*/
 void EstimateLimitOffsetCost(AccessPath *path);
 
-inline double FindOutputRowsForJoin(double left_rows, double right_rows,
+/// Estimate the costs and row count for a WINDOW AccessPath.
+void EstimateWindowCost(AccessPath *path);
+
+/**
+   Estimate the fan out for a left semijoin or a left antijoin. The fan out
+   is defined as the number of result rows, divided by the number of input
+   rows from the left hand relation. For a semijoin, J1:
+
+   SELECT ... FROM t1 WHERE EXISTS (SELECT ... FROM t2 WHERE predicate)
+
+   we know that the fan out of the corresponding inner join J2:
+
+   SELECT ... FROM t1, t2 WHERE predicate
+
+   is: F(J2) = CARD(t2) * SELECTIVITY(predicate) , where CARD(t2)=right_rows,
+   and SELECTIVITY(predicate)=edge.selectivity. If 'predicate' is a
+   deterministic function of t1 and t2 rows, then J1 is equivalent to an inner
+   join J3:
+
+   SELECT ... FROM t1 JOIN (SELECT DISTINCT f1,..fn FROM t2) d ON predicate
+
+   where f1,..fn are those fields from t2 that appear in the predicate.
+
+   Then F(J1) = F(J3) = F(J2) * CARD(d) / CARD(t2)
+        = CARD(d) * SELECTIVITY(predicate).
+
+   This function therefore collects f1..fn and estimates CARD(d). As a special
+   case, 'predicate' may be independent of t2. The query is then equivalent to:
+
+   SELECT ... FROM t1 WHERE predicate AND (SELECT COUNT(*) FROM t2) > 0
+
+   The fan out is then the selectivity of 'predicate' multiplied by the
+   probability of t2 having at least one row.
+
+   @param thd The current thread.
+   @param right_rows The number of input rows from the right hand relation.
+   @param edge Join edge.
+   @returns fan out.
+ */
+double EstimateSemijoinFanOut(THD *thd, double right_rows,
+                              const JoinPredicate &edge);
+
+/**
+   Estimate the number of output rows from joining two relations.
+   @param thd The current thread.
+   @param left_rows Number of rows in the left hand relation.
+   @param right_rows Number of rows in the right hand relation.
+   @param edge The join between the two relations.
+*/
+inline double FindOutputRowsForJoin(THD *thd, double left_rows,
+                                    double right_rows,
                                     const JoinPredicate *edge) {
-  double fanout = right_rows * edge->selectivity;
-  if (edge->expr->type == RelationalExpression::LEFT_JOIN) {
-    // For outer joins, every outer row produces at least one row (if none
-    // are matching, we get a NULL-complemented row).
-    // Note that this can cause inconsistent row counts; see bug #33550360
-    // and/or JoinHypergraph::has_reordered_left_joins.
-    fanout = std::max(fanout, 1.0);
-  } else if (edge->expr->type == RelationalExpression::SEMIJOIN) {
-    // Semi- and antijoin estimation is pretty tricky, since we want isn't
-    // really selectivity; we want the probability that at least one row
-    // is matching, which is something else entirely. However, given that
-    // we only have selectivity to work with, we don't really have anything
-    // better than to estimate it as a normal join and cap the result
-    // at selectivity 1.0 (ie., each outer row generates at most one inner row).
-    // Note that this can cause inconsistent row counts; see bug #33550360 and
-    // CostingReceiver::has_semijoin_with_possibly_clamped_child.
-    fanout = std::min(fanout, 1.0);
-  } else if (edge->expr->type == RelationalExpression::ANTIJOIN) {
-    // Antijoin are estimated as simply the opposite of semijoin (see above),
-    // but wrongly estimating 0 rows (or, of course, a negative amount) could be
-    // really bad, so we assume at least 10% coming out as a fudge factor.
-    // It's better to estimate too high than too low here.
-    fanout = std::max(1.0 - fanout, 0.1);
+  switch (edge->expr->type) {
+    case RelationalExpression::LEFT_JOIN:
+      // For outer joins, every outer row produces at least one row (if none
+      // are matching, we get a NULL-complemented row).
+      // Note that this can cause inconsistent row counts; see bug #33550360
+      // and/or JoinHypergraph::has_reordered_left_joins.
+      return left_rows * std::max(right_rows * edge->selectivity, 1.0);
+
+    case RelationalExpression::SEMIJOIN:
+      return left_rows * EstimateSemijoinFanOut(thd, right_rows, *edge);
+
+    case RelationalExpression::ANTIJOIN:
+      // Antijoin are estimated as simply the opposite of semijoin (see above),
+      // but wrongly estimating 0 rows (or, of course, a negative amount) could
+      // be really bad, so we assume at least 10% coming out as a fudge factor.
+      // It's better to estimate too high than too low here.
+      return left_rows *
+             std::max(1.0 - EstimateSemijoinFanOut(thd, right_rows, *edge),
+                      0.1);
+
+    case RelationalExpression::INNER_JOIN:
+    case RelationalExpression::STRAIGHT_INNER_JOIN:
+      return left_rows * right_rows * edge->selectivity;
+
+    case RelationalExpression::FULL_OUTER_JOIN:   // Not implemented.
+    case RelationalExpression::MULTI_INNER_JOIN:  // Should not appear here.
+    case RelationalExpression::TABLE:             // Should not appear here.
+      assert(false);
+      return 0;
+
+    default:
+      assert(false);
+      return 0;
   }
-  return left_rows * fanout;
 }
 
 #endif  // SQL_JOIN_OPTIMIZER_COST_MODEL_H_
