@@ -1,15 +1,16 @@
-/* Copyright (c) 2011, 2023, Oracle and/or its affiliates.
+/* Copyright (c) 2011, 2024, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
    as published by the Free Software Foundation.
 
-   This program is also distributed with certain software (including
+   This program is designed to work with certain software (including
    but not limited to OpenSSL) that is licensed under separate terms,
    as designated in a particular file or component or in included license
    documentation.  The authors of MySQL hereby grant you an additional
    permission to link the program and your derivative works with the
-   separately licensed software that they have included with MySQL.
+   separately licensed software that they have either included with
+   the program or referenced in the documentation.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -910,6 +911,23 @@ static size_t get_string_length(rpl_gno gno) {
   return len;
 }
 
+bool Gtid_set::contains_tags() const {
+  assert(tsid_map != nullptr);
+  for (const auto &tsid_it : tsid_map->get_sorted_sidno()) {
+    rpl_sidno sidno = tsid_it.second;
+    if (contains_sidno(sidno)) {
+      Const_interval_iterator ivit(this, sidno);
+      if (ivit.get() != nullptr) {
+        auto tsid = tsid_map->sidno_to_tsid(sidno);
+        if (tsid.is_tagged()) {
+          return true;
+        }
+      }
+    }
+  }
+  return false;
+}
+
 size_t Gtid_set::get_string_length(const Gtid_set::String_format *sf) const {
   assert(tsid_map != nullptr);
   if (tsid_lock != nullptr) tsid_lock->assert_some_wrlock();
