@@ -1,15 +1,16 @@
-/* Copyright (c) 2020, 2023, Oracle and/or its affiliates.
+/* Copyright (c) 2020, 2024, Oracle and/or its affiliates.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License, version 2.0,
 as published by the Free Software Foundation.
 
-This program is also distributed with certain software (including
+This program is designed to work with certain software (including
 but not limited to OpenSSL) that is licensed under separate terms,
 as designated in a particular file or component or in included license
 documentation.  The authors of MySQL hereby grant you an additional
 permission to link the program and your derivative works with the
-separately licensed software that they have included with MySQL.
+separately licensed software that they have either included with
+the program or referenced in the documentation.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -285,11 +286,6 @@ int log_sink_trad(void *instance [[maybe_unused]], log_line *ll) {
     }
 
     {
-      char internal_buff[LOG_BUFF_MAX];
-      const size_t buff_size = sizeof(internal_buff);
-      char *buff_line = internal_buff;
-      size_t len;
-
       if (!(out_types & LOG_ITEM_LOG_LABEL)) {
         label = (prio == ERROR_LEVEL) ? "ERROR" : log_label_from_prio(prio);
         label_len = strlen(label);
@@ -303,7 +299,11 @@ int log_sink_trad(void *instance [[maybe_unused]], log_line *ll) {
         iso_timestamp = buff_local_time;
         iso_len = strlen(buff_local_time);
       }
-
+#ifndef XTRABACKUP
+      char internal_buff[LOG_BUFF_MAX];
+      const size_t buff_size = sizeof(internal_buff);
+      char *buff_line = internal_buff;
+      size_t len;
       /*
         WL#11009 adds "error identifier" as a field in square brackets
         that directly precedes the error message. As a result, new
@@ -344,6 +344,13 @@ int log_sink_trad(void *instance [[maybe_unused]], log_line *ll) {
 
       // write log-event to log-file
       log_write_errstream(buff_line, len);
+#else
+      fprintf(stderr, "%.*s %u [%.*s] [MY-%06u] [%.*s] %.*s\n", (int)iso_len,
+              iso_timestamp, thread_id, (int)label_len, label, errcode,
+              (int)subsys_len, subsys, (int)msg_len, msg);
+      fflush(stderr);
+
+#endif /* !XTRABACKUP */
     }
   }
 
