@@ -1,15 +1,16 @@
-/* Copyright (c) 2008, 2023, Oracle and/or its affiliates.
+/* Copyright (c) 2008, 2024, Oracle and/or its affiliates.
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.
 
-  This program is also distributed with certain software (including
+  This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
-  separately licensed software that they have included with MySQL.
+  separately licensed software that they have either included with
+  the program or referenced in the documentation.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -139,9 +140,9 @@ struct sql_digest_storage {
       as the thread producing the digest is executing concurrently,
       without any lock enforced.
     */
-    size_t byte_count_copy = m_token_array_length < from->m_byte_count
-                                 ? m_token_array_length
-                                 : from->m_byte_count;
+    const size_t byte_count_copy = m_token_array_length < from->m_byte_count
+                                       ? m_token_array_length
+                                       : from->m_byte_count;
 
     if (byte_count_copy > 0) {
       m_full = from->m_full;
