@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.3.2.  */
+/* A Bison parser, made by GNU Bison 3.5.1.  */
 
 /* Bison interface for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2019 Free Software Foundation,
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2020 Free Software Foundation,
    Inc.
 
    This program is free software: you can redistribute it and/or modify
@@ -34,20 +34,28 @@
 /* Undocumented macros, especially those whose name start with YY_,
    are private implementation details.  Do not rely on them.  */
 
-#ifndef YY_MYSQL_MNT_JENKINS_WORKSPACE_PERCONA_XTRABACKUP_8_0_RELEASE_TEST_PERCONA_XTRABACKUP_SQL_SQL_YACC_H_INCLUDED
-# define YY_MYSQL_MNT_JENKINS_WORKSPACE_PERCONA_XTRABACKUP_8_0_RELEASE_TEST_PERCONA_XTRABACKUP_SQL_SQL_YACC_H_INCLUDED
+#ifndef YY_MY_SQL_PARSER_MNT_JENKINS_WORKSPACE_PERCONA_XTRABACKUP_8_0_RELEASE_TEST_PERCONA_XTRABACKUP_SQL_SQL_YACC_H_INCLUDED
+# define YY_MY_SQL_PARSER_MNT_JENKINS_WORKSPACE_PERCONA_XTRABACKUP_8_0_RELEASE_TEST_PERCONA_XTRABACKUP_SQL_SQL_YACC_H_INCLUDED
 /* Debug traces.  */
-#ifndef YYDEBUG
-# define YYDEBUG 0
-#endif
+#ifndef MY_SQL_PARSER_DEBUG
+# if defined YYDEBUG
 #if YYDEBUG
-extern int MYSQLdebug;
+#   define MY_SQL_PARSER_DEBUG 1
+#  else
+#   define MY_SQL_PARSER_DEBUG 0
+#  endif
+# else /* ! defined YYDEBUG */
+#  define MY_SQL_PARSER_DEBUG 0
+# endif /* ! defined YYDEBUG */
+#endif  /* ! defined MY_SQL_PARSER_DEBUG */
+#if MY_SQL_PARSER_DEBUG
+extern int my_sql_parser_debug;
 #endif
 
 /* Token type.  */
-#ifndef YYTOKENTYPE
-# define YYTOKENTYPE
-  enum yytokentype
+#ifndef MY_SQL_PARSER_TOKENTYPE
+# define MY_SQL_PARSER_TOKENTYPE
+  enum my_sql_parser_tokentype
   {
     ABORT_SYM = 258,
     ACCESSIBLE_SYM = 259,
@@ -341,29 +349,29 @@ extern int MYSQLdebug;
     LOOP_SYM = 547,
     LOW_PRIORITY = 548,
     LT = 549,
-    MASTER_AUTO_POSITION_SYM = 550,
-    MASTER_BIND_SYM = 551,
-    MASTER_CONNECT_RETRY_SYM = 552,
-    MASTER_DELAY_SYM = 553,
-    MASTER_HOST_SYM = 554,
-    MASTER_LOG_FILE_SYM = 555,
-    MASTER_LOG_POS_SYM = 556,
-    MASTER_PASSWORD_SYM = 557,
-    MASTER_PORT_SYM = 558,
-    MASTER_RETRY_COUNT_SYM = 559,
-    MASTER_SSL_CAPATH_SYM = 561,
-    MASTER_TLS_VERSION_SYM = 562,
-    MASTER_SSL_CA_SYM = 563,
-    MASTER_SSL_CERT_SYM = 564,
-    MASTER_SSL_CIPHER_SYM = 565,
-    MASTER_SSL_CRL_SYM = 566,
-    MASTER_SSL_CRLPATH_SYM = 567,
-    MASTER_SSL_KEY_SYM = 568,
-    MASTER_SSL_SYM = 569,
-    MASTER_SSL_VERIFY_SERVER_CERT_SYM = 570,
+    OBSOLETE_TOKEN_550 = 550,
+    OBSOLETE_TOKEN_551 = 551,
+    OBSOLETE_TOKEN_552 = 552,
+    OBSOLETE_TOKEN_553 = 553,
+    OBSOLETE_TOKEN_554 = 554,
+    OBSOLETE_TOKEN_555 = 555,
+    OBSOLETE_TOKEN_556 = 556,
+    OBSOLETE_TOKEN_557 = 557,
+    OBSOLETE_TOKEN_558 = 558,
+    OBSOLETE_TOKEN_559 = 559,
+    OBSOLETE_TOKEN_561 = 561,
+    OBSOLETE_TOKEN_562 = 562,
+    OBSOLETE_TOKEN_563 = 563,
+    OBSOLETE_TOKEN_564 = 564,
+    OBSOLETE_TOKEN_565 = 565,
+    OBSOLETE_TOKEN_566 = 566,
+    OBSOLETE_TOKEN_567 = 567,
+    OBSOLETE_TOKEN_568 = 568,
+    OBSOLETE_TOKEN_569 = 569,
+    OBSOLETE_TOKEN_570 = 570,
     MASTER_SYM = 571,
-    MASTER_USER_SYM = 572,
-    MASTER_HEARTBEAT_PERIOD_SYM = 573,
+    OBSOLETE_TOKEN_572 = 572,
+    OBSOLETE_TOKEN_573 = 573,
     MATCH = 574,
     MAX_CONNECTIONS_PER_HOUR = 575,
     MAX_QUERIES_PER_HOUR = 576,
@@ -756,8 +764,8 @@ extern int MYSQLdebug;
     RESOURCE_SYM = 963,
     SYSTEM_SYM = 964,
     VCPU_SYM = 965,
-    MASTER_PUBLIC_KEY_PATH_SYM = 966,
-    GET_MASTER_PUBLIC_KEY_SYM = 967,
+    OBSOLETE_TOKEN_966 = 966,
+    OBSOLETE_TOKEN_967 = 967,
     RESTART_SYM = 968,
     DEFINITION_SYM = 969,
     DESCRIPTION_SYM = 970,
@@ -779,10 +787,10 @@ extern int MYSQLdebug;
     OJ_SYM = 986,
     NETWORK_NAMESPACE_SYM = 987,
     RANDOM_SYM = 988,
-    MASTER_COMPRESSION_ALGORITHM_SYM = 989,
-    MASTER_ZSTD_COMPRESSION_LEVEL_SYM = 990,
+    OBSOLETE_TOKEN_989 = 989,
+    OBSOLETE_TOKEN_990 = 990,
     PRIVILEGE_CHECKS_USER_SYM = 991,
-    MASTER_TLS_CIPHERSUITES_SYM = 992,
+    OBSOLETE_TOKEN_992 = 992,
     REQUIRE_ROW_FORMAT_SYM = 993,
     PASSWORD_LOCK_TIME_SYM = 994,
     FAILED_LOGIN_ATTEMPTS_SYM = 995,
@@ -844,11 +852,22 @@ extern int MYSQLdebug;
     BULK_SYM = 1201,
     URL_SYM = 1202,
     GENERATE_SYM = 1203,
-    KEYWORD_USED_AS_IDENT = 1205,
-    KEYWORD_USED_AS_KEYWORD = 1206,
-    CONDITIONLESS_JOIN = 1207,
-    SUBQUERY_AS_EXPR = 1208,
-    EMPTY_FROM_CLAUSE = 1209
+    DOLLAR_QUOTED_STRING_SYM = 1204,
+    PARSE_TREE_SYM = 1205,
+    LOG_SYM = 1206,
+    GTIDS_SYM = 1207,
+    PARALLEL_SYM = 1208,
+    S3_SYM = 1209,
+    QUALIFY_SYM = 1210,
+    AUTO_SYM = 1211,
+    MANUAL_SYM = 1212,
+    BERNOULLI_SYM = 1213,
+    TABLESAMPLE_SYM = 1214,
+    KEYWORD_USED_AS_IDENT = 1216,
+    KEYWORD_USED_AS_KEYWORD = 1217,
+    CONDITIONLESS_JOIN = 1218,
+    PREFER_PARENTHESES = 1219,
+    EMPTY_FROM_CLAUSE = 1220
   };
 #endif
 /* Tokens.  */
@@ -1144,29 +1163,29 @@ extern int MYSQLdebug;
 #define LOOP_SYM 547
 #define LOW_PRIORITY 548
 #define LT 549
-#define MASTER_AUTO_POSITION_SYM 550
-#define MASTER_BIND_SYM 551
-#define MASTER_CONNECT_RETRY_SYM 552
-#define MASTER_DELAY_SYM 553
-#define MASTER_HOST_SYM 554
-#define MASTER_LOG_FILE_SYM 555
-#define MASTER_LOG_POS_SYM 556
-#define MASTER_PASSWORD_SYM 557
-#define MASTER_PORT_SYM 558
-#define MASTER_RETRY_COUNT_SYM 559
-#define MASTER_SSL_CAPATH_SYM 561
-#define MASTER_TLS_VERSION_SYM 562
-#define MASTER_SSL_CA_SYM 563
-#define MASTER_SSL_CERT_SYM 564
-#define MASTER_SSL_CIPHER_SYM 565
-#define MASTER_SSL_CRL_SYM 566
-#define MASTER_SSL_CRLPATH_SYM 567
-#define MASTER_SSL_KEY_SYM 568
-#define MASTER_SSL_SYM 569
-#define MASTER_SSL_VERIFY_SERVER_CERT_SYM 570
+#define OBSOLETE_TOKEN_550 550
+#define OBSOLETE_TOKEN_551 551
+#define OBSOLETE_TOKEN_552 552
+#define OBSOLETE_TOKEN_553 553
+#define OBSOLETE_TOKEN_554 554
+#define OBSOLETE_TOKEN_555 555
+#define OBSOLETE_TOKEN_556 556
+#define OBSOLETE_TOKEN_557 557
+#define OBSOLETE_TOKEN_558 558
+#define OBSOLETE_TOKEN_559 559
+#define OBSOLETE_TOKEN_561 561
+#define OBSOLETE_TOKEN_562 562
+#define OBSOLETE_TOKEN_563 563
+#define OBSOLETE_TOKEN_564 564
+#define OBSOLETE_TOKEN_565 565
+#define OBSOLETE_TOKEN_566 566
+#define OBSOLETE_TOKEN_567 567
+#define OBSOLETE_TOKEN_568 568
+#define OBSOLETE_TOKEN_569 569
+#define OBSOLETE_TOKEN_570 570
 #define MASTER_SYM 571
-#define MASTER_USER_SYM 572
-#define MASTER_HEARTBEAT_PERIOD_SYM 573
+#define OBSOLETE_TOKEN_572 572
+#define OBSOLETE_TOKEN_573 573
 #define MATCH 574
 #define MAX_CONNECTIONS_PER_HOUR 575
 #define MAX_QUERIES_PER_HOUR 576
@@ -1559,8 +1578,8 @@ extern int MYSQLdebug;
 #define RESOURCE_SYM 963
 #define SYSTEM_SYM 964
 #define VCPU_SYM 965
-#define MASTER_PUBLIC_KEY_PATH_SYM 966
-#define GET_MASTER_PUBLIC_KEY_SYM 967
+#define OBSOLETE_TOKEN_966 966
+#define OBSOLETE_TOKEN_967 967
 #define RESTART_SYM 968
 #define DEFINITION_SYM 969
 #define DESCRIPTION_SYM 970
@@ -1582,10 +1601,10 @@ extern int MYSQLdebug;
 #define OJ_SYM 986
 #define NETWORK_NAMESPACE_SYM 987
 #define RANDOM_SYM 988
-#define MASTER_COMPRESSION_ALGORITHM_SYM 989
-#define MASTER_ZSTD_COMPRESSION_LEVEL_SYM 990
+#define OBSOLETE_TOKEN_989 989
+#define OBSOLETE_TOKEN_990 990
 #define PRIVILEGE_CHECKS_USER_SYM 991
-#define MASTER_TLS_CIPHERSUITES_SYM 992
+#define OBSOLETE_TOKEN_992 992
 #define REQUIRE_ROW_FORMAT_SYM 993
 #define PASSWORD_LOCK_TIME_SYM 994
 #define FAILED_LOGIN_ATTEMPTS_SYM 995
@@ -1647,30 +1666,41 @@ extern int MYSQLdebug;
 #define BULK_SYM 1201
 #define URL_SYM 1202
 #define GENERATE_SYM 1203
-#define KEYWORD_USED_AS_IDENT 1205
-#define KEYWORD_USED_AS_KEYWORD 1206
-#define CONDITIONLESS_JOIN 1207
-#define SUBQUERY_AS_EXPR 1208
-#define EMPTY_FROM_CLAUSE 1209
+#define DOLLAR_QUOTED_STRING_SYM 1204
+#define PARSE_TREE_SYM 1205
+#define LOG_SYM 1206
+#define GTIDS_SYM 1207
+#define PARALLEL_SYM 1208
+#define S3_SYM 1209
+#define QUALIFY_SYM 1210
+#define AUTO_SYM 1211
+#define MANUAL_SYM 1212
+#define BERNOULLI_SYM 1213
+#define TABLESAMPLE_SYM 1214
+#define KEYWORD_USED_AS_IDENT 1216
+#define KEYWORD_USED_AS_KEYWORD 1217
+#define CONDITIONLESS_JOIN 1218
+#define PREFER_PARENTHESES 1219
+#define EMPTY_FROM_CLAUSE 1220
 
 /* Value type.  */
 
 /* Location type.  */
-#if ! defined YYLTYPE && ! defined YYLTYPE_IS_DECLARED
-typedef struct YYLTYPE YYLTYPE;
-struct YYLTYPE
+#if ! defined MY_SQL_PARSER_LTYPE && ! defined MY_SQL_PARSER_LTYPE_IS_DECLARED
+typedef struct MY_SQL_PARSER_LTYPE MY_SQL_PARSER_LTYPE;
+struct MY_SQL_PARSER_LTYPE
 {
   int first_line;
   int first_column;
   int last_line;
   int last_column;
 };
-# define YYLTYPE_IS_DECLARED 1
-# define YYLTYPE_IS_TRIVIAL 1
+# define MY_SQL_PARSER_LTYPE_IS_DECLARED 1
+# define MY_SQL_PARSER_LTYPE_IS_TRIVIAL 1
 #endif
 
 
 
-int MYSQLparse (class THD *YYTHD, class Parse_tree_root **parse_tree);
+int my_sql_parser_parse (class THD *YYTHD, class Parse_tree_root **parse_tree);
 
-#endif /* !YY_MYSQL_MNT_JENKINS_WORKSPACE_PERCONA_XTRABACKUP_8_0_RELEASE_TEST_PERCONA_XTRABACKUP_SQL_SQL_YACC_H_INCLUDED  */
+#endif /* !YY_MY_SQL_PARSER_MNT_JENKINS_WORKSPACE_PERCONA_XTRABACKUP_8_0_RELEASE_TEST_PERCONA_XTRABACKUP_SQL_SQL_YACC_H_INCLUDED  */
