@@ -1,17 +1,18 @@
 /*****************************************************************************
 
-Copyright (c) 1995, 2023, Oracle and/or its affiliates.
+Copyright (c) 1995, 2024, Oracle and/or its affiliates.
 
 This program is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License, version 2.0, as published by the
 Free Software Foundation.
 
-This program is also distributed with certain software (including but not
-limited to OpenSSL) that is licensed under separate terms, as designated in a
-particular file or component or in included license documentation. The authors
-of MySQL hereby grant you an additional permission to link the program and
-your derivative works with the separately licensed software that they have
-included with MySQL.
+This program is designed to work with certain software (including
+but not limited to OpenSSL) that is licensed under separate terms,
+as designated in a particular file or component or in included license
+documentation.  The authors of MySQL hereby grant you an additional
+permission to link the program and your derivative works with the
+separately licensed software that they have either included with
+the program or referenced in the documentation.
 
 This program is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -666,7 +667,8 @@ static inline bool fsp_descr_page(const page_id_t &page_id,
 @param[in] end_ptr Buffer end.
 @param[in] block Block or nullptr.
 @return end of log record or nullptr */
-byte *fsp_parse_init_file_page(byte *ptr, byte *end_ptr, buf_block_t *block);
+const byte *fsp_parse_init_file_page(const byte *ptr, const byte *end_ptr,
+                                     buf_block_t *block);
 
 #ifdef UNIV_BTR_PRINT
 /** Writes info of a segment. */
