@@ -14,15 +14,15 @@ function test_do()
   vlog "-- transition_key: ${transition_key} --"
   vlog "-- keyring_type: ${keyring_type} --"
   if [[ "$transition_key" = "generate" ]] ; then
-    backup_options="--generate-transition-key"
+    backup_options="--generate-transition-key --xtrabackup-plugin-dir=${plugin_dir}"
     prepare_options="--xtrabackup-plugin-dir=${plugin_dir} ${keyring_args}"
     copyback_options="--xtrabackup-plugin-dir=${plugin_dir} ${keyring_args}"
   elif [[ "$transition_key" = "none" ]] ; then
-    backup_options=
+    backup_options="--xtrabackup-plugin-dir=${plugin_dir}"
     prepare_options="--xtrabackup-plugin-dir=${plugin_dir} ${keyring_args}"
     copyback_options="--xtrabackup-plugin-dir=${plugin_dir} ${keyring_args}"
   else
-    backup_options="--transition-key=$transition_key"
+    backup_options="--transition-key=$transition_key --xtrabackup-plugin-dir=${plugin_dir}"
     prepare_options="--transition-key=$transition_key"
     copyback_options="--transition-key=$transition_key --xtrabackup-plugin-dir=${plugin_dir} ${keyring_args}"
   fi
@@ -36,7 +36,7 @@ function test_do()
   run_cmd $MYSQL $MYSQL_ARGS test -e "SELECT @@server_uuid"
 
   # PXB-1540: XB removes and recreate keyring file of 0 size
-  xtrabackup --backup --target-dir=$topdir/backup0
+  xtrabackup --backup --target-dir=$topdir/backup0 $backup_options
 
   rm -rf $topdir/backup0
 
@@ -81,6 +81,9 @@ ALTER INSTANCE ROTATE INNODB MASTER KEY;
 INSERT INTO t1 SELECT * FROM t1;
 EOF
 
+  # wait for InnoDB to flush all dirty pages
+  innodb_wait_for_flush_all
+
   $MYSQL $MYSQL_ARGS -e 'START TRANSACTION; INSERT INTO t1 SELECT * FROM t1; SELECT SLEEP(200000);' test &
   uncommitted_id=$!
 
@@ -102,13 +105,11 @@ EOF
   xtrabackup --prepare --export --target-dir=$topdir/backup \
        $prepare_options
 
-  # check that stats works
   if [ -z ${plugin_load+x} ]; then
     plugin_load_arg=""
   else
     plugin_load_arg="--plugin-load=${plugin_load}"
   fi
- # xtrabackup --stats --datadir=$topdir/backup ${plugin_load_arg}
 
   # make sure t1.ibd is still encrypted
   vlog "-- running strings "
@@ -124,6 +125,7 @@ EOF
   xtrabackup --copy-back --target-dir=$topdir/backup
 
 if [[ "${KEYRING_TYPE}" = "component" ]] || [[ "${KEYRING_TYPE}" = "both" ]]; then
+  cp ${instance_local_manifest}  $mysql_datadir
   cp ${keyring_component_cnf} $mysql_datadir
 fi
 
@@ -169,6 +171,7 @@ fi
     if [[ "${KEYRING_TYPE}" = "component" ]] || [[ "${KEYRING_TYPE}" = "both" ]];
     then
       vlog "copying component config back to datadir"
+      cp ${instance_local_manifest}  $mysql_datadir
       cp ${keyring_component_cnf} $mysql_datadir
     fi
     start_server
@@ -257,6 +260,7 @@ function keyring_extra_tests()
   xtrabackup --copy-back --target-dir=$topdir/backup1
   if [[ "${KEYRING_TYPE}" = "component" ]] || [[ "${KEYRING_TYPE}" = "both" ]];
   then
+    cp ${instance_local_manifest}  $mysql_datadir
     cp ${keyring_component_cnf} $mysql_datadir
   fi
   start_server
