@@ -28,5 +28,5 @@ xtrabackup --backup --slave-info --safe-slave-backup --target-dir=$topdir/backup
 cat $topdir/backup/xtrabackup_binlog_info
 run_cmd egrep -q '^mysql-bin.[0-9]+[[:space:]]+[0-9]+$' \
     $topdir/backup/xtrabackup_binlog_info
-run_cmd egrep -q '^CHANGE MASTER TO MASTER_LOG_FILE='\''mysql-bin.[0-9]+'\'', MASTER_LOG_POS=[0-9]+;$' \
+run_cmd egrep -q '^CHANGE REPLICATION SOURCE TO SOURCE_LOG_FILE='\''mysql-bin.[0-9]+'\'', SOURCE_LOG_POS=[0-9]+;$' \
     $topdir/backup/xtrabackup_slave_info
