@@ -4,9 +4,10 @@
 
 require_server_version_higher_than 5.7.10
 
+KEYRING_TYPE="component"
+. inc/keyring_common.sh
 . inc/keyring_file.sh
-
-start_server
+configure_server_with_component
 
 mysql -e "CREATE TABLE t (a INT) ENCRYPTION='y'" test
 
