@@ -4,9 +4,11 @@
 
 require_server_version_higher_than 5.7.10
 
+KEYRING_TYPE="component"
+. inc/keyring_common.sh
 . inc/keyring_file.sh
+configure_server_with_component
 
-start_server --early-plugin-load=keyring_file.so --keyring-file-data=$keyring_file_plugin --server_id=10
 
 run_cmd $MYSQL $MYSQL_ARGS test <<EOF
 
@@ -34,8 +36,7 @@ innodb_wait_for_flush_all
 
 cat $mysql_datadir/auto.cnf
 
-xtrabackup --backup --target-dir=$topdir/backup \
-	   --keyring-file-data=$keyring_file_plugin --server_id=10
+xtrabackup --backup --target-dir=$topdir/backup ${keyring_args}
 
 cat $topdir/backup/backup-my.cnf
 
@@ -49,7 +50,7 @@ EOF
 
 xtrabackup --backup --incremental-basedir=$topdir/backup \
            --target-dir=$topdir/inc1 \
-           --keyring-file-data=$keyring_file_plugin --server_id=10
+           --xtrabackup-plugin-dir=${plugin_dir} ${keyring_args}
 
 run_cmd $MYSQL $MYSQL_ARGS test <<EOF
 
@@ -61,24 +62,20 @@ EOF
 
 xtrabackup --backup --incremental-basedir=$topdir/inc1 \
 	   --target-dir=$topdir/inc2 \
-	   --keyring-file-data=$keyring_file_plugin --server_id=10
+	   --xtrabackup-plugin-dir=${plugin_dir} ${keyring_args}
 
 ${XB_BIN} --prepare --apply-log-only --target-dir=$topdir/backup \
-	  --keyring-file-data=$keyring_file_plugin \
 	  --xtrabackup-plugin-dir=${plugin_dir} ${keyring_args}
 
 ${XB_BIN} --prepare --apply-log-only --incremental-dir=$topdir/inc1 \
 	  --target-dir=$topdir/backup \
-	  --keyring-file-data=$keyring_file_plugin \
 	  --xtrabackup-plugin-dir=${plugin_dir} ${keyring_args}
 
 ${XB_BIN} --prepare --apply-log-only --incremental-dir=$topdir/inc2 \
 	  --target-dir=$topdir/backup \
-	  --keyring-file-data=$keyring_file_plugin \
 	  --xtrabackup-plugin-dir=${plugin_dir} ${keyring_args}
 
 ${XB_BIN} --prepare --target-dir=$topdir/backup \
-	  --keyring-file-data=$keyring_file_plugin \
 	  --xtrabackup-plugin-dir=${plugin_dir} ${keyring_args}
 
 stop_server
@@ -87,16 +84,18 @@ rm -rf $mysql_datadir
 
 xtrabackup --copy-back --target-dir=$topdir/backup
 
+cp ${instance_local_manifest}  $mysql_datadir
+cp ${keyring_component_cnf} $mysql_datadir
+
 cat > $mysql_datadir/auto.cnf <<EOF
 [auto]
 server_uuid=8a94f357-aab4-11df-86ab-c80aa9429562
 EOF
 
-start_server --early-plugin-load=keyring_file.so --keyring_file_data=$keyring_file_plugin --server_id=200
+start_server --server_id=200
 
 run_cmd $MYSQL $MYSQL_ARGS test <<EOF
 SELECT @@server_id;
 SELECT @@server_uuid;
-SELECT @@keyring_file_data;
 SELECT SUM(c1) FROM t1;
 EOF
