@@ -3,6 +3,10 @@
 #              creates redo logs in wrong directory
 #
 
+MYSQLD_EXTRA_MY_CNF_OPTS="
+innodb-data-file-path=ibdata1:100M;ibdata2:10M:autoextend
+"
+
 start_server
 
 ${MYSQL} ${MYSQL_ARGS} -e "CREATE TABLE t1 (id int primary key)" test
@@ -17,4 +21,14 @@ xtrabackup --backup --target-dir=$topdir/backup-inc --incremental-basedir=$topdi
 xtrabackup --prepare --apply-log-only --target-dir=$topdir/backup
 xtrabackup --prepare --incremental-dir=$topdir/backup-inc --target-dir=$topdir/backup
 
-test -f $topdir/backup/ib_logfile0 || die "Log files are not found in full backup directory"
+test -d $topdir/backup/#innodb_redo || die "redo directory are not found in full backup directory"
+
+stop_server
+
+rm -rf $mysql_datadir/*
+
+xtrabackup --copy-back --target-dir=$topdir/backup
+
+start_server
+
+${MYSQL} ${MYSQL_ARGS} -e "SELECT * FROM t1" test
