@@ -5,7 +5,7 @@
 
 . inc/common.sh
 
-options="innodb_log_files_in_group innodb_log_file_size"
+options=""
 
 # innodb_page_size is supported in XtraDB 5.1+ and InnoDB 5.6+
 if is_xtradb || is_server_version_higher_than 5.6.0
@@ -13,21 +13,9 @@ then
     options="$options innodb_page_size"
 fi
 
-# innodb_fast_checksum is supported in XtraDB 5.1/5.5
-if is_xtradb && is_server_version_lower_than 5.6.0
-then
-    options="$options innodb_fast_checksum"
-fi
-
-# innodb_log_block_size is only supported in XtraDB
-if is_xtradb
-then
-    options="$options innodb_log_block_size"
-fi
-
 start_server
 
-innobackupex --no-timestamp $topdir/backup
+xtrabackup --backup --target-dir=$topdir/backup
 
 # test presence of options
 for option in $options ; do
