@@ -23,9 +23,11 @@ start_server --log-bin=`hostname`-bin --binlog-format=ROW \
              --wsrep_provider_options="base_port=${galera_port}${pdebug}" \
              --wsrep_node_address=$ADDR
 
+has_backup_locks && skip_test "Requires server without backup locks support"
+
 # take a backup with stream mode
 mkdir -p $topdir/backup
-innobackupex --galera-info --stream=xbstream $topdir/backup > $topdir/backup/stream.xbs
+xtrabackup --backup --galera-info --stream=xbstream --target-dir=$topdir/backup > $topdir/backup/stream.xbs
 
 xbstream -xv -C $topdir/backup < $topdir/backup/stream.xbs
 if [ -f $topdir/backup/xtrabackup_galera_info ] ; then
