@@ -2,37 +2,36 @@
 # Bug #711166: Partitioned tables are not correctly handled by the
 #              --databases and --tables-file options of innobackupex,
 #              and by the --tables option of xtrabackup.
-#              Testcase covers using --include option with InnoDB
+#              Testcase covers using --tables option with InnoDB
 #              database and --stream mode
 ########################################################################
 
 . inc/common.sh
 . inc/ib_part.sh
 
-start_server --innodb_file_per_table
+start_server --innodb_file_per_table --innodb_directories=$TEST_VAR_ROOT/remote 
 
 require_partitioning
 
-# Create MyISAM partitioned table
-ib_part_init $topdir MyISAM
+# Create InnoDB partitioned table
+ib_part_init $TEST_VAR_ROOT/remote InnoDB
 
 # Saving the checksum of original table
 checksum_a=`checksum_table test test`
 
 # Take a backup
 mkdir -p $topdir/backup
-innobackupex --stream=tar --include='^(mysql.*|performance_schema.*|test.test)$' $topdir/backup > $topdir/backup/backup.tar
-$TAR ixvf $topdir/backup/backup.tar -C $topdir/backup 
-$TAR cvhf $topdir/backup/backup11.tar $mysql_datadir/test/*
+xtrabackup --backup --stream=xbstream --tables='^(mysql.*|performance_schema.*|test.test)$' --target-dir=$topdir/backup > $topdir/backup/backup.xbs
+xbstream -xv < $topdir/backup/backup.xbs -C $topdir/backup
 
-innobackupex --apply-log $topdir/backup
+xtrabackup --prepare --target-dir=$topdir/backup
 
 vlog "Backup taken"
 
 stop_server
 
 # Restore partial backup
-ib_part_restore $topdir $mysql_datadir
+ib_part_restore $TEST_VAR_ROOT/remote $mysql_datadir
 
 start_server
 
