@@ -4,6 +4,7 @@
 
 require_xtradb
 require_server_version_higher_than 5.6.13
+require_server_version_lower_than 5.7.0
 
 function test_with_algorithm()
 {
@@ -21,7 +22,7 @@ innodb_log_checksum_algorithm=$1
 
     load_sakila
 
-    innobackupex --no-timestamp $topdir/backup
+    xtrabackup --backup --target-dir=$topdir/backup
 
     egrep '^innodb_log_checksum_algorithm='$1'$' $topdir/backup/backup-my.cnf
 
@@ -31,11 +32,11 @@ innodb_log_checksum_algorithm=$1
 
     rm -rf $MYSQLD_DATADIR/*
 
-    run_cmd ${IB_BIN} \
-        ${IB_ARGS/\/--defaults-file=*my.cnf/$topdir\/backup\/backup-my.cnf} \
-        --apply-log $topdir/backup
+    run_cmd ${XB_BIN} \
+        ${XB_ARGS/\/--defaults-file=*my.cnf/$topdir\/backup\/backup-my.cnf} \
+        --prepare --target-dir=$topdir/backup
 
-    innobackupex --copy-back $topdir/backup
+    xtrabackup --copy-back --target-dir=$topdir/backup
 
     start_server
 
