@@ -3,7 +3,7 @@
 ############################################################################
 
 stream_format=xbstream
-stream_extract_cmd="xbstream -xv <"
+stream_extract_cmd="xbstream -xv --parallel=16 <"
 xtrabackup_options="--parallel=16"
 
 . inc/xb_stream_common.sh
