@@ -30,6 +30,11 @@ append_arg_to_args () {
     args="$args "$(shell_quote_string "$1")
 }
 
+switch_to_vault_repo() {
+    sed -i 's/mirrorlist/#mirrorlist/g' /etc/yum.repos.d/CentOS-*
+    sed -i 's|#\s*baseurl=http://mirror.centos.org|baseurl=http://vault.centos.org|g' /etc/yum.repos.d/CentOS-*
+}
+
 parse_arguments() {
     pick_args=
     if test "$1" = PICK-ARGS-FROM-ARGV
@@ -216,6 +221,8 @@ enable_venv(){
             source /opt/rh/devtoolset-7/enable
             source /opt/rh/rh-python36/enable
             export CMAKE_BIN="cmake3"
+        elif [ "${RHEL}" -eq 8 ]; then
+            source /opt/rh/gcc-toolset-12/enable
         fi
     fi
 }
@@ -234,16 +241,24 @@ install_deps() {
     CURPLACE=$(pwd)
     if [ "$OS" == "rpm" ]
     then
+        if [ $RHEL = 7 ]; then
+            switch_to_vault_repo
+        fi
         yum -y install git wget yum-utils curl
         yum install -y https://repo.percona.com/yum/percona-release-latest.noarch.rpm
-        if [ $RHEL = 9 ]; then
-            yum-config-manager --enable ol9_distro_builder
-            yum-config-manager --enable ol9_codeready_builder
-            yum -y install https://dl.fedoraproject.org/pub/epel/epel-release-latest-9.noarch.rpm
-        #else
-            # add_percona_yum_repo
+        if [ x"$ARCH" = "xx86_64" ]; then
+            if [ $RHEL = 9 ]; then
+                yum-config-manager --enable ol9_distro_builder
+                yum-config-manager --enable ol9_codeready_builder
+                yum -y install https://dl.fedoraproject.org/pub/epel/epel-release-latest-9.noarch.rpm
+            else
+                add_percona_yum_repo
+                percona-release enable tools testing
+            fi
+        else
+            yum-config-manager --enable ol"${RHEL}"_codeready_builder
+            yum -y install epel-release
         fi
-        percona-release enable tools testing
         if [ ${RHEL} = 8 -o ${RHEL} = 9 ]; then
             PKGLIST+=" binutils-devel python3-pip python3-setuptools"
             PKGLIST+=" libcurl-devel cmake libaio-devel zlib-devel libev-devel bison make"
@@ -252,12 +267,15 @@ install_deps() {
             if [ $RHEL = 9 ]; then
                 PKGLIST+=" rsync procps-ng-devel python3-sphinx gcc gcc-c++"
             else
-                yum-config-manager --enable powertools
-                #wget https://jenkins.percona.com/downloads/rpm/procps-ng-devel-3.3.15-6.el8.x86_64.rpm
-                wget --no-check-certificate https://downloads.percona.com/downloads/TESTING/issue-CUSTO83/procps-ng-devel-3.3.15-6.el8.x86_64.rpm
-                yum -y install ./procps-ng-devel-3.3.15-6.el8.x86_64.rpm
-                rm procps-ng-devel-3.3.15-6.el8.x86_64.rpm
-                PKGLIST+=" libarchive"
+                if [ x"$ARCH" = "xx86_64" ]; then
+                    yum-config-manager --enable powertools
+                    wget --no-check-certificate https://downloads.percona.com/downloads/packaging/procps-ng-devel-3.3.15-6.el8.x86_64.rpm
+                    yum -y install ./procps-ng-devel-3.3.15-6.el8.x86_64.rpm
+                    rm procps-ng-devel-3.3.15-6.el8.x86_64.rpm
+                    PKGLIST+=" libarchive"
+                else
+                    PKGLIST+=" rsync python3-sphinx libarchive procps-ng-devel gcc gcc-c++"
+                fi
             fi
             until yum -y install ${PKGLIST}; do
                 echo "waiting"
@@ -267,13 +285,27 @@ install_deps() {
                 DEVTOOLSET10_PKGLIST+=" gcc-toolset-10-gcc-c++ gcc-toolset-10-binutils"
                 DEVTOOLSET10_PKGLIST+=" gcc-toolset-10-valgrind gcc-toolset-10-valgrind-devel gcc-toolset-10-libatomic-devel"
                 DEVTOOLSET10_PKGLIST+=" gcc-toolset-10-libasan-devel gcc-toolset-10-libubsan-devel gcc-toolset-10-annobin"
-                until yum -y install ${DEVTOOLSET10_PKGLIST}; do
-                    echo "waiting"
-                    sleep 1
-                done
-                update-alternatives --install /usr/bin/gcc gcc /opt/rh/gcc-toolset-10/root/usr/bin/gcc 10
-                update-alternatives --install /usr/bin/g++ g++ /opt/rh/gcc-toolset-10/root/usr/bin/g++ 10
-                gcc --version
+                DEVTOOLSET12_PKGLIST+=" gcc-toolset-12-gcc-c++ gcc-toolset-12-binutils"
+                DEVTOOLSET12_PKGLIST+=" gcc-toolset-12-libasan-devel gcc-toolset-12-libubsan-devel gcc-toolset-12-annobin-annocheck gcc-toolset-12-annobin-plugin-gcc"
+                if [ x"$ARCH" = "xx86_64" ]; then
+                    yum -y install centos-release-stream
+                    until yum -y install ${DEVTOOLSET10_PKGLIST}; do
+                        echo "waiting"
+                        sleep 1
+                    done
+                    update-alternatives --install /usr/bin/gcc gcc /opt/rh/gcc-toolset-10/root/usr/bin/gcc 10
+                    update-alternatives --install /usr/bin/g++ g++ /opt/rh/gcc-toolset-10/root/usr/bin/g++ 10
+                    gcc --version
+                    yum -y remove centos-release-stream
+                else
+                    until yum -y install ${DEVTOOLSET12_PKGLIST}; do
+                        echo "waiting"
+                        sleep 1
+                    done
+                    update-alternatives --install /usr/bin/gcc gcc /opt/rh/gcc-toolset-12/root/usr/bin/gcc 12
+                    update-alternatives --install /usr/bin/g++ g++ /opt/rh/gcc-toolset-12/root/usr/bin/g++ 12
+                    gcc --version
+                fi
             fi
         else
             until yum -y install epel-release centos-release-scl; do
@@ -281,6 +313,9 @@ install_deps() {
                 sleep 1
                 echo "waiting"
             done
+            if [ $RHEL = 7 ]; then
+                switch_to_vault_repo
+            fi
             until yum -y makecache; do
                 yum clean all
                 sleep 1
@@ -322,10 +357,14 @@ install_deps() {
         PKGLIST+=" cmake debhelper libaio-dev libncurses-dev libtool libz-dev libsasl2-dev vim-common"
         PKGLIST+=" libgcrypt-dev libev-dev lsb-release libudev-dev"
         PKGLIST+=" build-essential rsync libdbd-mysql-perl libnuma1 socat libssl-dev patchelf libicu-dev"
-        if [ "${OS_NAME}" != "bookworm" ]; then
-            PKGLIST+=" libprocps-dev"
-        else
+        if [ "${OS_NAME}" == "bookworm" -o "${OS_NAME}" == "noble" ]; then
             PKGLIST+=" libproc2-dev"
+        else
+            PKGLIST+=" libprocps-dev"
+        fi
+        if [ "${OS_NAME}" == "noble" ]; then
+            wget http://archive.ubuntu.com/ubuntu/pool/main/o/openssl/libssl1.1_1.1.1f-1ubuntu2_amd64.deb
+            dpkg -i libssl1.1_1.1.1f-1ubuntu2_amd64.deb
         fi
         if [ "${OS_NAME}" == "bionic" ]; then
             PKGLIST+=" gcc-8 g++-8"
@@ -333,7 +372,7 @@ install_deps() {
         if [ "${OS_NAME}" == "focal" ]; then
             PKGLIST+=" gcc-10 g++-10"
         fi
-        if [ "${OS_NAME}" == "focal" -o "${OS_NAME}" == "bullseye" -o "${OS_NAME}" == "bookworm" -o "${OS_NAME}" == "jammy" ]; then
+        if [ "${OS_NAME}" == "focal" -o "${OS_NAME}" == "bullseye" -o "${OS_NAME}" == "bookworm" -o "${OS_NAME}" == "jammy" -o "${OS_NAME}" == "noble" ]; then
             PKGLIST+=" python3-sphinx python3-docutils"
         else
             PKGLIST+=" python-sphinx python-docutils"
@@ -422,6 +461,9 @@ build_srpm(){
     cd $WORKDIR/rpmbuild/SPECS
     tar vxzf $WORKDIR/$TARFILE --wildcards '*/storage/innobase/xtrabackup/utils/*.spec' --strip=5
     #
+    sed -i "/^%changelog/a - Release ${VERSION}-${RELEASE}" percona-xtrabackup.spec
+    sed -i "/^%changelog/a * $(date "+%a") $(date "+%b") $(date "+%d") $(date "+%Y") Percona Development Team <info@percona.com> - ${VERSION}-${RELEASE}" percona-xtrabackup.spec
+    #
     cd $WORKDIR
     #
     mv -fv $TARFILE $WORKDIR/rpmbuild/SOURCES
@@ -512,7 +554,7 @@ build_source_deb(){
 
     echo "DEB_RELEASE=${DEB_RELEASE}" >> ${CURDIR}/percona-xtrabackup-8.0.properties
 
-    NEWTAR=${NAME}-83_${VERSION}.orig.tar.gz
+    NEWTAR=${NAME}-84_${VERSION}.orig.tar.gz
     mv ${TARFILE} ${NEWTAR}
 
     tar xzf ${NEWTAR}
