@@ -1,16 +1,17 @@
 /*
-   Copyright (c) 2010, 2023, Oracle and/or its affiliates.
+   Copyright (c) 2010, 2024, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
    as published by the Free Software Foundation.
 
-   This program is also distributed with certain software (including
+   This program is designed to work with certain software (including
    but not limited to OpenSSL) that is licensed under separate terms,
    as designated in a particular file or component or in included license
    documentation.  The authors of MySQL hereby grant you an additional
    permission to link the program and your derivative works with the
-   separately licensed software that they have included with MySQL.
+   separately licensed software that they have either included with
+   the program or referenced in the documentation.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -351,10 +352,11 @@ public class QueryDomainTypeImpl<T> implements QueryDomainType<T> {
      * depends on the where clause and the bound parameter values.
      * 
      * @param context the query context, including the bound parameters
+     * @param limit maximum number of instances to be deleted
      * @return the number of instances deleted
      * @throws ClusterJUserException if not all parameters are bound
      */
-    public int deletePersistentAll(QueryExecutionContext context) {
+    public int deletePersistentAll(QueryExecutionContext context, long limit) {
         SessionSPI session = context.getSession();
         // calculate what kind of scan is needed
         // if no where clause, scan the entire table
@@ -364,6 +366,8 @@ public class QueryDomainTypeImpl<T> implements QueryDomainType<T> {
         context.setExplain(explain);
         int result = 0;
         int errorCode = 0;
+        if(limit < 1)
+            return result;
         Index storeIndex;
         session.startAutoTransaction();
         Operation op = null;
@@ -417,7 +421,7 @@ public class QueryDomainTypeImpl<T> implements QueryDomainType<T> {
                     // set additional filter conditions
                     where.filterCmpValue(context, (IndexScanOperation)op);
                     // delete results of the scan; don't abort if no row found
-                    result = session.deletePersistentAll((IndexScanOperation)op, false);
+                    result = session.deletePersistentAll((IndexScanOperation)op, false, limit);
                     break;
                 }
 
@@ -432,7 +436,7 @@ public class QueryDomainTypeImpl<T> implements QueryDomainType<T> {
                         where.filterCmpValue(context, (ScanOperation)op);
                     }
                     // delete results of the scan; don't abort if no row found
-                    result = session.deletePersistentAll((ScanOperation)op, false);
+                    result = session.deletePersistentAll((ScanOperation)op, false, limit);
                     break;
                 }
 
